/* Copyright Statement:
 *
 * (C) 2017  Airoha Technology Corp. All rights reserved.
 *
 * This software/firmware and related documentation ("Airoha Software") are
 * protected under relevant copyright laws. The information contained herein
 * is confidential and proprietary to Airoha Technology Corp. ("Airoha") and/or its licensors.
 * Without the prior written permission of Airoha and/or its licensors,
 * any reproduction, modification, use or disclosure of Airoha Software,
 * and information contained herein, in whole or in part, shall be strictly prohibited.
 * You may only use, reproduce, modify, or distribute (as applicable) Airoha Software
 * if you have agreed to and been bound by the applicable license agreement with
 * Airoha ("License Agreement") and been granted explicit permission to do so within
 * the License Agreement ("Permitted User").  If you are not a Permitted User,
 * please cease any access or use of Airoha Software immediately.
 * BY OPENING THIS FILE, RECEIVER HEREBY UNEQUIVOCALLY ACKNOWLEDGES AND AGREES
 * THAT AIROHA SOFTWARE RECEIVED FROM AIROHA AND/OR ITS REPRESENTATIVES
 * ARE PROVIDED TO RECEIVER ON AN "AS-IS" BASIS ONLY. AIROHA EXPRESSLY DISCLAIMS ANY AND ALL
 * WARRANTIES, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NONINFRINGEMENT.
 * NEITHER DOES AIROHA PROVIDE ANY WARRANTY WHATSOEVER WITH RESPECT TO THE
 * SOFTWARE OF ANY THIRD PARTY WHICH MAY BE USED BY, INCORPORATED IN, OR
 * SUPPLIED WITH AIROHA SOFTWARE, AND RECEIVER AGREES TO LOOK ONLY TO SUCH
 * THIRD PARTY FOR ANY WARRANTY CLAIM RELATING THERETO. RECEIVER EXPRESSLY ACKNOWLEDGES
 * THAT IT IS RECEIVER'S SOLE RESPONSIBILITY TO OBTAIN FROM ANY THIRD PARTY ALL PROPER LICENSES
 * CONTAINED IN AIROHA SOFTWARE. AIROHA SHALL ALSO NOT BE RESPONSIBLE FOR ANY AIROHA
 * SOFTWARE RELEASES MADE TO RECEIVER'S SPECIFICATION OR TO CONFORM TO A PARTICULAR
 * STANDARD OR OPEN FORUM. RECEIVER'S SOLE AND EXCLUSIVE REMEDY AND AIROHA'S ENTIRE AND
 * CUMULATIVE LIABILITY WITH RESPECT TO AIROHA SOFTWARE RELEASED HEREUNDER WILL BE,
 * AT AIROHA'S OPTION, TO REVISE OR REPLACE AIROHA SOFTWARE AT ISSUE,
 * OR REFUND ANY SOFTWARE LICENSE FEES OR SERVICE CHARGE PAID BY RECEIVER TO
 * AIROHA FOR SUCH AIROHA SOFTWARE AT ISSUE.
 */

#ifndef _LOG_H_
#define _LOG_H_

#include "types.h"
#include "stdio.h"

#define MAX_LOG_STRING 96
#define LOG_STRING __attribute__ ((section (".log.string")))
#define LOG_STRING_SYS1 __attribute__ ((section (".log.system1.string")))
#define LOG_STRING_SYS2 __attribute__ ((section (".log.system2.string")))


typedef enum {
    PRINT_LEVEL_DEBUG,
    PRINT_LEVEL_INFO,
    PRINT_LEVEL_WARNING,
    PRINT_LEVEL_ERROR
} PRINTF_LEVEL;

typedef U32 LOG_PRINTF_GROUP;
/* user group start from 0 */
#define LOG_USER1			((LOG_PRINTF_GROUP)1<<0)
#define LOG_USER2			((LOG_PRINTF_GROUP)1<<1)
#define LOG_USER3			((LOG_PRINTF_GROUP)1<<2)
#define LOG_USER4			((LOG_PRINTF_GROUP)1<<3)
#define LOG_USER5			((LOG_PRINTF_GROUP)1<<4)

/* module group start from 5 */
#define LOG_OS				((LOG_PRINTF_GROUP)1<<5)
#define LOG_DM2L			((LOG_PRINTF_GROUP)1<<6)
#define LOG_DSP				((LOG_PRINTF_GROUP)1<<7)
#define LOG_GERNERAL        ((LOG_PRINTF_GROUP)1<<8)

/* app info start from 10*/
#define LOG_APP_Connection	((LOG_PRINTF_GROUP)1<<10)
#define LOG_APP_A2DP		((LOG_PRINTF_GROUP)1<<11)
#define LOG_APP_AVRCP		((LOG_PRINTF_GROUP)1<<12)
#define LOG_APP_HFP			((LOG_PRINTF_GROUP)1<<13)
#define LOG_APP_USR			((LOG_PRINTF_GROUP)1<<14)
#define LOG_APP_STATE		((LOG_PRINTF_GROUP)1<<15)
#define LOG_APP_DSP			((LOG_PRINTF_GROUP)1<<16)
#define LOG_APP_SYSTEM		((LOG_PRINTF_GROUP)1<<17)

/* Profile */
#define LOG_PROFILE_A2DP	((LOG_PRINTF_GROUP)1<<18)
#define LOG_PROFILE_AVRCP	((LOG_PRINTF_GROUP)1<<19)
#define LOG_PROFILE_HFP		((LOG_PRINTF_GROUP)1<<20)
#define LOG_PROFILE_OTHER   ((LOG_PRINTF_GROUP)1<<21)


/* BT LIB */
#define LOG_AVCTP           ((LOG_PRINTF_GROUP)1<<22)
#define LOG_L2CAP           ((LOG_PRINTF_GROUP)1<<23)
#define LOG_RFCOMM          ((LOG_PRINTF_GROUP)1<<24)
#define LOG_SDP             ((LOG_PRINTF_GROUP)1<<25)
#define LOG_GAP             ((LOG_PRINTF_GROUP)1<<26)
#define LOG_AVDTP           ((LOG_PRINTF_GROUP)1<<27)


/* system info start from 28 */
#define LOG_COREDUMP		((LOG_PRINTF_GROUP)1<<28)
#define LOG_PRINT			((LOG_PRINTF_GROUP)1<<29)
#define LOG_MEMDUMP			((LOG_PRINTF_GROUP)1<<30)
#define LOG_ASSERT			((LOG_PRINTF_GROUP)1<<31)

#define LOG_D(group, message, argc, ...) \
do { \
     LOG_STRING static const char msg_id_string[] = message; \
     logPrint(group, \
              PRINT_LEVEL_DEBUG, \
              ((char*)msg_id_string), \
              (argc),\
              ##__VA_ARGS__); \
} while (0)


#define LOG_I(group, message, argc, ...) \
do { \
    LOG_STRING static const char msg_id_string[] = message; \
    logPrint(group, \
            PRINT_LEVEL_INFO, \
            ((char*)msg_id_string), \
            (argc),\
            ##__VA_ARGS__); \
} while (0)

#define LOG_W(group, message, argc, ...) \
do { \
     LOG_STRING static const msg_id_string[] = message; \
     logPrint(group, \
              PRINT_LEVEL_WARNING, \
              ((char*)msg_id_string), \
              (argc),\
              ##__VA_ARGS__); \
} while (0)

#define LOG_E(group, message, argc, ...) \
do { \
     LOG_STRING static const char msg_id_string[] = message; \
     logPrint(group, \
              PRINT_LEVEL_ERROR, \
              ((char*)msg_id_string), \
              (argc),\
              ##__VA_ARGS__); \
} while (0)

EXTERN char exampleLogString[];
EXTERN char testLogString[];
EXTERN char exampleLogString1[];


EXTERN char SystemPowerOff[];
EXTERN char SystemPowerOffFail[];
EXTERN char SystemLowPowerMode[];
EXTERN char SystemNormalPowerMode[];
EXTERN char tickInfo[];
EXTERN char isrInfo[];
EXTERN char isrStackSize[];
EXTERN char taskInfo0[];
EXTERN char taskInfo1[];
EXTERN char taskBackTrace[];
EXTERN char taskNameString[][MAX_LOG_STRING];
EXTERN char taskNameString2[][MAX_LOG_STRING];
EXTERN char taskState[][MAX_LOG_STRING];
EXTERN char memoryInfo[];
EXTERN char heapInfo[];
EXTERN char memoryInfoString[][MAX_LOG_STRING];
EXTERN char wakeUpInfo[];
EXTERN char heapBlockInfo[];
EXTERN char heapFragInfo[];
EXTERN char heapCrash[];
EXTERN char airapptest[];



EXTERN char DSP_WarningString[][MAX_LOG_STRING];

EXTERN char DSP_INFO_CreateCallbackStream[];
EXTERN char DSP_INFO_CloseCallbackStream[];
EXTERN char DSP_INFO_AnalogInputGainString[];
EXTERN char DSP_INFO_AnalogOutputGainString[];
EXTERN char DSP_INFO_DigitalInputGainString[];
EXTERN char DSP_INFO_DigitalOutputGainString[];
EXTERN char DSP_INFO_SourceConfiguration[];
EXTERN char DSP_INFO_SinkConfiguration[];
EXTERN char DSP_INFO_EnableSrc[];
EXTERN char DSP_INFO_DisableSrcClk[];
EXTERN char DSP_INFO_EnableAudioClock[];
EXTERN char DSP_INFO_DisableAudioClock[];
EXTERN char DSP_INFO_Audio3wireSetting[];
EXTERN char DSP_INFO_EnableMceAudio[];
EXTERN char DSP_INFO_DisableMceAudio[];
EXTERN char DSP_INFO_ModifyAudioChannelSel[];
EXTERN char DSP_INFO_UpdateFeatureCommand[] ;
EXTERN char DSP_INFO_UpdateFeatureMips[];
EXTERN char DSP_INFO_MceSyncParaPush[];
EXTERN char DSP_INFO_MceSyncParaPop[];
EXTERN char DSP_INFO_StreamDeinit[];
EXTERN char DSP_INFO_ScoPacketCheck[];
EXTERN char DSP_INFO_MicBiasCtrl[];
EXTERN char DSP_INFO_AdioOutputDelayTime[];
EXTERN char DSP_INFO_AudioMutePenalties[];
EXTERN char DSP_INFO_AudioMutePenaltyClear[];
EXTERN char DSP_INFO_AudioInputDevice[];
EXTERN char DSP_INFO_AudioOutputDevice[];
EXTERN char DSP_INFO_AudioI2SMclkConfigure[];
EXTERN char DSP_INFO_DebugString[];

EXTERN char DSP_MemoryFlush[];
EXTERN char DSP_MemoryCorruptionLogString[];
EXTERN char DSP_MemoryCorruptionHeaderLogString[];
EXTERN char DSP_MemoryCorruptionEOBLogString[];
EXTERN char DSP_MemoryCorruptionFeatureLogString[];


EXTERN char DM2L_TxLmpLogString[];
EXTERN char DM2L_RxLmpLogString[];
EXTERN char DM2L_TxLlcpLogString[];
EXTERN char DM2L_RxLlcpLogString[];
EXTERN char DM2L_RxHciCmdLogString[];
EXTERN char DM2L_TxHciEvtLogString[];
EXTERN char DM2L_RedundantStopEncLogString[];

/* Stream A2dp */
EXTERN char StreamA2dp_RemainPacketLogString[];
EXTERN char StreamA2dp_StreamSendMsgToAppLogString[];
EXTERN char StreamA2dp_AudioOutOfSyncNotiLogString[];
EXTERN char StreamA2dp_AudioAdjustClockLogString[];
EXTERN char StreamA2dp_ModifyAbnormatWaitLogString[];
EXTERN char StreamA2dp_CloseRx2PktBDALogString[];
EXTERN char StreamA2dp_OpenRx2pktBDALogString[];
EXTERN char StreamA2dp_CloseRx1PktBDALogString[];
EXTERN char StreamA2dp_OpenRx1pktBDALogString[];
EXTERN char StreamA2dp_CustomizedLatencyLogString[];
EXTERN char StreamA2dp_GetFrameSize0LogString[];
EXTERN char StreamA2dp_WrongSyncWordLogString[];
EXTERN char StreamA2dp_GetFrameSize0LogString1[];
EXTERN char StreamA2dp_WaitFrame2LogString[];
EXTERN char StreamA2dp_WaitFrame1LogString[];
EXTERN char StreamA2dp_PktDropCurrLogString[];
EXTERN char StreamA2dp_FirtPktNoLogString1[];
EXTERN char StreamA2dp_WaitFrameDueToOutOfSyncLogString[];
EXTERN char StreamA2dp_WaitDebugLogString[];
EXTERN char StreamA2dp_MuteDebugLogString[];
EXTERN char StreamA2dp_AudioInfo2CrcErrLogString1[];
EXTERN char StreamA2dp_AudioInfo1LogString[];
EXTERN char StreamA2dp_AudioInfoCrcErrLogString1[];
EXTERN char StreamA2dp_RoleChangeLogString1[];

/* Stream Ama*/
EXTERN char	StreamAma_FrameSizeZeroLogString[];
EXTERN char StreamAma_FrameNumLogString[];

/* AMA */
EXTERN char AMA_GetLinkIdxString[];
EXTERN char AMA_UpdateUpgradeTransportDataString[];
EXTERN char AMA_GetEmptyLinkInfoString[];
EXTERN char AMA_ClearLinkInfoString[];
EXTERN char AMA_RhoLinkManagerGetDataLengthString[];
EXTERN char AMA_RhoLinkManagerGetDataNoAmaLinkString[];
EXTERN char AMA_RhoLinkManagerGetDataOkString[];
EXTERN char AMA_RhoLinkManagerApplyAgentFailString[];
EXTERN char AMA_RhoLinkManagerApplyAgentOkString[];
EXTERN char AMA_RhoLinkManagerApplyPartnerOkString[];
EXTERN char AMA_NvkeyGetVarDataString[];
EXTERN char AMA_NvkeyUpdateVarDataString[];
EXTERN char AMA_NvkeyVarDataOobString[];
EXTERN char AMA_NvkeyVarDataBdAddrString[];

/* AMA BLE */
EXTERN char AMA_BleEnableAdvBdAString[];
EXTERN char AMA_BleAccessRxDescString[];
EXTERN char	AMA_BleDeviceStateString[];
EXTERN char	AMA_BleKeyIdString[];
EXTERN char AMA_BleSetAdvEnableCfmString[];
EXTERN char AMA_BleConnectedString[];
EXTERN char	AMA_BleDeinitString[];
EXTERN char AMA_BleDisableAdvString[];
EXTERN char AMA_BleEnableAdvString[];
EXTERN char	AMA_BleDisconnString[];
EXTERN char AMA_BleTxStateErrorString[];
EXTERN char AMA_BleTxString[];
EXTERN char AMA_BleTxCccdString[];
EXTERN char AMA_BleGetDataLengthString[];
EXTERN char AMA_BleGetDataNoAmaLinkString[];
EXTERN char AMA_BleGetDataNoGapLinkString[];
EXTERN char AMA_BleGetDataOkString[];
EXTERN char AMA_BleApplyAgentNoGapLinkString[];
EXTERN char AMA_BleApplyAgentOkString[];
EXTERN char AMA_BleApplyPartnerOkString[];

/* AMA SPP */
EXTERN char AMA_SppNullSinkString[];
EXTERN char AMA_SppStateSinkString[];
EXTERN char AMA_SppNullLinkInfoString[];
EXTERN char AMA_SppInvalidClaimString[];
EXTERN char AMA_SppStatusString[];
EXTERN char AMA_SppConnIndHandlerString[];
EXTERN char AMA_SppGetDataLengthString[];
EXTERN char AMA_SppGetDataNoAmaLinkString[];
EXTERN char AMA_SppGetDataNoSppLinkString[];
EXTERN char AMA_SppGetDataOkString[];
EXTERN char AMA_SppApplyAgentNoEmptyLinkString[];
EXTERN char AMA_SppApplyAgentOkString[];
EXTERN char AMA_SppApplyPartnerOkString[];

/* TRSPX APP*/
EXTERN char APP_TrspxBtTimerString[];
EXTERN char APP_TrspxBtStartServiceString[];
EXTERN char APP_TrspxBtConnCfm1String[];
EXTERN char APP_TrspxBtConnCfm2String[];
EXTERN char APP_TrspxBtDisconnCfmString[];
EXTERN char APP_TrspxBtUartTxString[];
EXTERN char APP_TrspxBtRxDoneString[];
EXTERN char APP_TrspxBtRegAllProfileString[];
EXTERN char APP_TrspxUartTxString[];
EXTERN char APP_TrspxUartClaimFailString[];
EXTERN char APP_TrspxUartBtTxString[];
EXTERN char APP_TrspxUartBtTxTimeoutString[];
EXTERN char APP_TrspxUartTimerString[];

/* TRSPX */
EXTERN char TRSPX_BleConnectedString[];

EXTERN char SM_AddAuthList1String[];
EXTERN char SM_AddAuthList2String[];
EXTERN char SM_AddAuthList3String[];
EXTERN char SM_GetAuthListString[];

EXTERN char SM_WriteLtk1String[];
EXTERN char SM_WriteLtk2String[];
EXTERN char SM_WriteLtk3String[];
EXTERN char SM_ReadLtk1String[];
EXTERN char SM_ReadLtk2String[];

EXTERN char APP_KeySwitchPowerOnNeed[];
EXTERN char APP_KeyLogString[];
EXTERN char APP_EvtKeyLogString[];
EXTERN char APP_EvtKeyRHOLogString[];

EXTERN char APP_AddStateLogString[];
EXTERN char APP_InsertStateLogString[];
EXTERN char APP_RmvStateLogString[];
EXTERN char APP_ReplaceStateLogString[];
EXTERN char APP_CleanNestStateLogString[];

EXTERN char APP_PushMediaEvtLogString[];
EXTERN char APP_MediaEvtLogString[] ;
EXTERN char APP_VPRTStartLogString[];
EXTERN char APP_VPRTStopLogString[];
EXTERN char APP_MediaEndLogString[];
EXTERN char APP_MediaCantFindNvKeyLogString[];
EXTERN char APP_MediaInitSucessLogString[];
EXTERN char APP_MediaNeedToSyncLogString[];
EXTERN char APP_MediaNotNeedToSyncLogString[];

EXTERN char APP_MediaAgentEventInHFPstring[];
EXTERN char APP_MediaPartnerEventInHFPstring[];
EXTERN char APP_MediaEventPlayUnderHFPStatetring[];


EXTERN char APP_SetLedBGPatternLogString[];
EXTERN char APP_SetLedFGPatternLogString[];
EXTERN char APP_SetLedFilterPatternLogString[];
EXTERN char APP_CancelLedFilterLogString[];
EXTERN char APP_ResumeLedLogString[];

EXTERN char APP_LinkHistoryClearEntryLogString[];
EXTERN char APP_LinkHistoryClearNormalLogString[];
EXTERN char APP_LinkHistoryClearAirLogString[];

EXTERN char APP_PMLoadLogString[];
EXTERN char APP_PMUnLoadLogString[];
EXTERN char APP_PMActivateLogString[];
EXTERN char PM_ProfileRegisteredCfmLog[];

EXTERN char APP_DSPSCOStartLogString[];
EXTERN char APP_DSPSCOStopLogString[];
EXTERN char APP_DSPSCOTxFailLogString[];
EXTERN char APP_DSPSCORxFailLogString[];
EXTERN char APP_DSPSCOSuccessLogString[];

EXTERN char APP_DSPStreamStartLogString[];
EXTERN char APP_DSPStreamStopLogString[];

EXTERN char APP_DSPSideToneStartLogString[];
EXTERN char APP_DSPSideToneStopLogString[];

EXTERN char APP_DSPVPStartLogString[];
EXTERN char APP_DSPVPStopLogString[];

EXTERN char APP_DSPRTStartLogString[];
EXTERN char APP_DSPRTStopLogString[];

EXTERN char APP_DSPMP3StartLogString[];
EXTERN char APP_DSPMP3StartedLogString[];
EXTERN char APP_DSPMP3StartFailLogString[];
EXTERN char APP_DSPMP3StartFailAlreadyRegisteredLogString[];
EXTERN char APP_DSPMP3StopLogString[];
EXTERN char APP_DSPMP3NotInitLogString[];
EXTERN char APP_DSPMP3InitFailLogString[];
EXTERN char APP_DSPMP3InitSuccessfulLogString[];
EXTERN char APP_DSPMP3SourceEndLogString[];
EXTERN char APP_DSPMP3SinkEndLogString[];
EXTERN char APP_DSPMP3ModeControlLogString[];
EXTERN char APP_DSPMP3PauseLogString[];
EXTERN char APP_DSPMP3ResumeLogString[];
EXTERN char APP_DSPMP3ForwardLogString[];
EXTERN char APP_DSPMP3BackwardLogString[];
EXTERN char APP_DSPMP3FileOpenLogString[];

EXTERN char APP_ChgBatStatusLogString[];
EXTERN char APP_ChgBatLevelLogString[];
EXTERN char APP_ChgBatMonitorPercentLogString[];
EXTERN char APP_ChgBatEnterDeepSleepString[];
EXTERN char APP_ChgBatInitString[];
EXTERN char APP_ChgBatOutputLowString[];
EXTERN char APP_ChgBatInputStatusString[];
EXTERN char APP_ChgBatChgOutSetOutputHighString[];
EXTERN char APP_ChgBatGpioYInterruptString[];
EXTERN char APP_ChgBatChgInThenPowerOffString[];
EXTERN char APP_ChgBatChgOutPowerLogString[];
EXTERN char APP_ChgBatNotDummyDelayLogString[];
EXTERN char APP_ChgBatDummpyCplLogString[];
EXTERN char APP_ChgBat_DRV_CHARGER_MSG_GPIO_YLogString[];
EXTERN char APP_ChgBat_DUMMY_DELAY_IDLogString[];
EXTERN char APP_ChgBat_app_ChgBat_DrvEvtHandlerLogString[];
EXTERN char APP_ChgBat_DuringChgOutDummyDelayReleaseTimerLogString[];
EXTERN char APP_ChgBat_DuringDummyDelayAndcaseLogString[];
EXTERN char APP_ChgBat_DuringDummyDelay1LogString[];
EXTERN char APP_ChgBat_DuringDummyDelay2LogString[];

EXTERN char APP_DSPAncStartLogString[];
EXTERN char APP_DSPAncStartFailedLogString[];
EXTERN char APP_DSPAncStopLogString[];
EXTERN char APP_DSPAncStopFailedLogString[];
EXTERN char APP_DSPAncChangeLogString[];

EXTERN char APP_AudioStreamStartSuccessfulLogString[];
EXTERN char APP_AudioStreamStartFailedLogString[];
EXTERN char APP_AudioStreamStopSuccessfulLogString[];
EXTERN char APP_AudioStreamStopFailedLogString[];
EXTERN char APP_AudioStreamDSPSuspendLogString[];
EXTERN char APP_AudioStreamRealTimeDSPSuspendLogString[];
EXTERN char APP_AudioStreamRealTimeDSPResumeLogString[];
EXTERN char APP_AudioStreamClearDspInfoLogString[];
EXTERN char APP_AudioStreamSetDspLogString[];

EXTERN char APP_DSPStartSuccessfulLogString[];
EXTERN char APP_DSPStartFailedLogString[];
EXTERN char APP_DSPStopSuccessfulLogString[];
EXTERN char APP_DSPStopFailedLogString[];
EXTERN char APP_AudioTypeLogString[][MAX_LOG_STRING];

EXTERN char APP_AudioTransferToAGLogString[];
EXTERN char APP_AudioTransferToDUTLogString[];

EXTERN char APP_DSPLineInNoSourceLogString[];
EXTERN char APP_DSPLineInNoSinkLogString[];
EXTERN char APP_DSPLineInTransformFailLogString[];
EXTERN char APP_DSPLineInTransformOKLogString[];
EXTERN char APP_DSPLineInStopCloseLogString[];
EXTERN char APP_DSPLineInNoExistCloseLogString[];

EXTERN char APP_CallStatusLogString[];

EXTERN char APP_VoiceCommandString[];
EXTERN char APP_VoiceCommandStartString[];
EXTERN char APP_VoiceCommandEndString[];
EXTERN char APP_VoiceCommandNvkeyInitSuccessString[];
EXTERN char APP_VoiceCommandNvkeyInitFailString[];

EXTERN char APP_AudioDSPNvkeyInitString[];
EXTERN char APP_AudioDSPNvkeyReadOutputPathString[];
EXTERN char APP_AudioDSPNvkeyReadAudioInputString[];
EXTERN char APP_AudioDSPNvkeyReadVoiceInputString[];
EXTERN char APP_AudioDSPNvkeyReadAudioChannelString[];
EXTERN char APP_AudioDSPNvkeyIsFeatureOnString[];

EXTERN char APP_AudioDrvSendVPStopCmdString[];
EXTERN char APP_AudioDrvSendRTStopCmdString[];

EXTERN char APP_AudioRegSetCurrentLinkAudioDeviceString[];
EXTERN char APP_AudioRegSetCurrentSystemAudioDeviceString[];
EXTERN char APP_AudioRegPauseCurrentMusicString[];
EXTERN char APP_AudioRegRecordDeviceString[];
EXTERN char APP_AudioRegRecordSystemString[];
EXTERN char APP_AudioRegDeleteDeviceString[];
EXTERN char APP_AudioRegDeleteSystemString[];
EXTERN char APP_AudioRegDeleteErrorString[];
EXTERN char APP_AudioRegResumeOtherErrorString[];
EXTERN char APP_AudioRegFillRhoDataErrorString[];
EXTERN char APP_AudioRegAssignRhoDataErrorString[];
EXTERN char APP_AudioRegCurrentAndInDevice[];
EXTERN char APP_KeyIndexLogString[][MAX_LOG_STRING];
EXTERN char APP_ActionLogString[][MAX_LOG_STRING];
EXTERN char APP_KeyEventLogString[][MAX_LOG_STRING];
EXTERN char APP_StateLogString[][MAX_LOG_STRING];
EXTERN char APP_MediaEvent1LogString[][MAX_LOG_STRING];
EXTERN char APP_MediaEvent2LogString[][MAX_LOG_STRING];
EXTERN char APP_MediaEvent3LogString[][MAX_LOG_STRING];
EXTERN char APP_VPLogString[][MAX_LOG_STRING];
EXTERN char APP_RTLogString[][MAX_LOG_STRING];
EXTERN char APP_VPRTLogString[][MAX_LOG_STRING];
EXTERN char APP_ProfileLogString[][MAX_LOG_STRING];
EXTERN char APP_BatStatusLogString[][MAX_LOG_STRING];

EXTERN char APP_MicMuteOnLogString[];
EXTERN char APP_MicMuteOffLogString[];

EXTERN char APP_CheckAiroThruCanPlayFail[];
EXTERN char APP_CheckAiroThruCanPlaySuccess[];
EXTERN char APP_IsAiroThruOpened[];
EXTERN char APP_IsAiroThruClosed[];
EXTERN char APP_AiroThruStartSuccess[];
EXTERN char APP_AiroThruStartFail[];
EXTERN char APP_AiroThruStartFail2[];
EXTERN char APP_AiroThruStopSuccess[];
EXTERN char APP_AiroThruStopFail[];

EXTERN char APP_RemoteSpkVolSetLogString[];
EXTERN char APP_RemoteMicVolSetLogString[];
EXTERN char APP_VolumeMaxLogString[];
EXTERN char APP_VolumeMinLogString[];
EXTERN char APP_A2dpVolUpDownSetLogString[];
EXTERN char APP_A2dpVolRemoteSetLogString[];
EXTERN char APP_Mp3VolUpDownSetLogString[];
EXTERN char APP_ScoMicVolUpDownSetLogString[];
EXTERN char APP_ScoMicVolRemoteSetLogString[];
EXTERN char APP_ScoMicVolTopStateLogString[];
EXTERN char APP_ScoVolUpDownSetLogString[];
EXTERN char APP_ScoVolRemoteSetLogString[];
EXTERN char APP_ScoVolTopStateLogString[];
EXTERN char APP_VpRtVolUpDownSetLogString[];
EXTERN char APP_SetSoundLevelToDSPLogString[];
EXTERN char APP_VolComponentLogString[][MAX_LOG_STRING];
EXTERN char APP_SetSoundLevelWrongLogString[];
EXTERN char APP_AiroThruVolUpDownSetLogString[];
EXTERN char APP_AiroThruCycleVolumeLogString[];
EXTERN char APP_LoadVCGainTableLogString[];
EXTERN char APP_LoadATGainTableLogString[];

EXTERN char APP_PEQGroupLoadLogString[];
EXTERN char APP_PEQGroupChangeLogString[];
EXTERN char APP_PEQGroupSetLogString[];
EXTERN char APP_NotActiveComponentLogString[];
EXTERN char APP_ForceUsePEQLogString[];
EXTERN char APP_NotForceUsePEQLogString[];
EXTERN char APP_PEQGroupAndModeLogString[];
EXTERN char APP_GetPEQParaNvkeyFailLogString1[];
EXTERN char APP_GetPEQParaNvkeyFailLogString2[];
EXTERN char APP_SendPEQToDSPLogString[];
EXTERN char APP_RealTimePEQLogString[];
EXTERN char APP_PeqComponentLogString[][MAX_LOG_STRING];
EXTERN char APP_PeqPhaseLogString[][MAX_LOG_STRING];
EXTERN char APP_GetParaAddrByNvkeyIDFailLogString1[];
EXTERN char APP_GetParaAddrByNvkeyIDFailLogString2[];


EXTERN char APP_RealTimePEQSyncTimeClockToStartLogString[];
EXTERN char APP_RealTimePEQAgentEndLogString[];
EXTERN char APP_RealTimePEQPartnerEndLogString[];
EXTERN char APP_RealTimePEQPlayingTimerLogString[];
EXTERN char APP_RealTimePEQPhaseLengthLogString[];
EXTERN char APP_RealTimePEQDataLogString[];
EXTERN char APP_RealTimePEQPartnerPicoLogString[];
EXTERN char APP_RealTimePEQPartnerTimeToStartString[];
EXTERN char APP_RealTimePEQFillRHODataErrorLogString[];
EXTERN char APP_RealTimePEQAssignRHODataErrorLogString[];


EXTERN char APP_CallHoldActiveLogString[][MAX_LOG_STRING];
EXTERN char APP_CallActiveLogString[][MAX_LOG_STRING];
EXTERN char APP_CallSetupLogString[][MAX_LOG_STRING];

EXTERN char APP_VoiceCommandLogString[][MAX_LOG_STRING];

EXTERN char APP_SetVoicePromptLanguageString[];

EXTERN char MSG_CallbackTimeConsuming[];
EXTERN char MSG_MessageSendInternalFromISR_Return3[];
EXTERN char MSG_MessageSendInternalFromISR_Return2[];
EXTERN char MSG_MessageSendInternalFromISR_Return1[];
EXTERN char MSG_MessageSendInternalFromISR_Return1DPC[];
EXTERN char MSG_MessageSendInternal_Return3[];
EXTERN char MSG_MessageSendInternal_Return2[];
EXTERN char MSG_MessageSendInternal_Return1[];
EXTERN char MSG_MessageSendInternal_Return1DPC[];
EXTERN char MSG_PendingStatus[];
EXTERN char MSG_StartDelayMessageFromISR[];
EXTERN char MSG_StartDelayMessage[];
EXTERN char MSG_DPCCallback[];
EXTERN char MSG_CallDelayedMessageHandler[];
EXTERN char MSG_CancelDelayMessage[];
EXTERN char MSG_MessageDumpPendingString[];
EXTERN char MSG_MessageNullHandler[];
EXTERN char MSG_MessageDPCCallbackEnter[];
EXTERN char MSG_MessageDPCCallbackLeave[];

EXTERN char NVKEY_LOG_RAMBufferedWriting[];
EXTERN char NVKEY_LOG_RAMBufferedFlushed[];
EXTERN char NVKEY_LOG_SectorSwapping[];
EXTERN char NVKEY_LOG_Write[];
EXTERN char NVKEY_LOG_CleanInvalidThreshold[];
EXTERN char NVKEY_LOG_SectorStatusReport[];
EXTERN char NVKEY_LOG_NVKEYNotFound[];
EXTERN char NVKEY_LOG_NVKEYDecryptionCRCError[];
EXTERN char NVKEY_LOG_NVKEYDecryptionLengthTooShort[];
EXTERN char NVKEY_LOG_NVKEYDecryptionNoMemory[];
EXTERN char NVKEY_LOG_NVKEYWriteError[];
EXTERN char NVKEY_LOG_NVKEYWriteSameContents[];
EXTERN char NVKEY_LOG_NVKEYFlashAddressDoubleEnter[];
EXTERN char NVKEY_LOG_AddNonExistedNVKEY_Non_FOTA[];
EXTERN char NVKEY_LOG_AddNonExistedNVKEY_FOTA[];
EXTERN char NVKEY_LOG_NVKEY_GetFlashAddress_Wrong_Tag[];
EXTERN char NVKEY_LOG_Enter_NVKEY_WriteFullKey[];
EXTERN char NVKEY_LOG_Enter_NVKEY_ReclaimCheck[];
EXTERN char NVKEY_LOG_Enter_NVKEY_ReadFullKey[];
EXTERN char NVKEY_LOG_Enter_NVKEY_Next[];
EXTERN char NVKEY_LOG_Enter_NVKEY_GetPayloadFlashAddress[];
EXTERN char NVKEY_LOG_Enter_NVKEY_GetPayloadLength[];
EXTERN char NVKEY_LOG_Enter_NVKEY_Flash_Access_Disable[];
EXTERN char NVKEY_LOG_Enter_NVKEY_Flash_Access_Enable[];
EXTERN char NVKEY_LOG_Enter_NVKEY_SetDecryptionKey[];
EXTERN char NVKEY_LOG_Enter_NVKEY_GetPayloadFlashAddress_Enter[];
EXTERN char NVKEY_LOG_Enter_NVKEY_GetPayloadFlashAddress_Leave[];
EXTERN char NVKEY_LOG_Semaphore_Take[];
EXTERN char NVKEY_LOG_Semaphore_Release[];

EXTERN char ROFS_LOG_BaseAddressNotFound[];
EXTERN char ROFS_LOG_FileNotFound[];

EXTERN char FLS_MetFileLengthZero[];
EXTERN char FLS_SDCardReadInterval[];

EXTERN char APP_SetQosCmdLogString[];
EXTERN char APP_QosCmdCfmLogString[];

EXTERN char APP_RealtimePeqUnhandleLogString[];
EXTERN char APP_RealtimePeqUndefinedLogString[];
EXTERN char APP_RealtimePeqSuspendDspLogString[];
EXTERN char APP_RealtimePeqResumeDspLogString[];
EXTERN char APP_RealtimePeqUpdateLogString[];
EXTERN char APP_RealtimePeqSaveStatusLogString[];

EXTERN char APP_ReconnAddListFailLogString[];
//EXTERN char APP_ReconnAddListBdaddrLogString[];
EXTERN char APP_ReconnAddListMemFailLogString[];
EXTERN char APP_ReconnAddListGetTag1FailLogString[];
EXTERN char APP_ReconnAddListGetTag2FailLogString[];
EXTERN char APP_ReconnStartACLExistLogString[];
EXTERN char APP_ReconnStartSucessLogString[];
EXTERN char APP_ReconnAddLinkLossLogString[];
EXTERN char APP_ReconnectAddListLogString[];
EXTERN char APP_ReconnectStopLogString[];
EXTERN char APP_ReconnectStopLogString2[];
EXTERN char APP_ReconnectStartActiveString[];
EXTERN char APP_ReconnectStartMiscDetachAndTypeString[];
EXTERN char APP_ReconnectStopNoTargetString[];
EXTERN char APP_ReconnectProfileMaskString[];
EXTERN char APP_ReconnectNoListString[];
EXTERN char APP_ReconnectProfileNotReadyString[];
EXTERN char APP_ReconnectCheckString[];
EXTERN char APP_ReconnectStopRetryString[];
EXTERN char APP_ReconnectDeleteProfileMaskString[];
EXTERN char APP_ReconnectDeleteProfileMaskString2[];
EXTERN char APP_ReconnectDeleteInvalidListString[];
EXTERN char APP_ReconnectDeleteInvalidListByBdAddrString[];
EXTERN char APP_ReconnectDeleteListString[];
EXTERN char APP_ReconnectPartnerRejectReconnect[];
EXTERN char APP_Reconnect[];
EXTERN char APP_ReconnectPartnerRejectReconnectString[];
EXTERN char APP_ReconnectCurTgtIdxNotInvalidString[];
EXTERN char APP_ReconnectStopAndClearString[];
EXTERN char APP_ReconnectAddListByModeString[];
EXTERN char APP_ReconnectSetTypeString[];
EXTERN char APP_ReconnectSetProfileMaskString[];
EXTERN char APP_ReconnectSetDataString[];
EXTERN char APP_ReconnectString1[];
EXTERN char APP_ReconnectString2[];
EXTERN char APP_ReconnectString3[];
EXTERN char APP_ReconnectAclOpenTimeOut[];
EXTERN char APP_ReconnectPutQueueIdxString[];
EXTERN char APP_ReconnectPourQueueNumString[];
EXTERN char APP_ReconnectPourQueueTypeString[];

EXTERN char APP_ReconnectCurrentActiveLinkCNTFailString[];
EXTERN char APP_ReconnectEnterSuperReconnectString[];
EXTERN char APP_ReconnectReconnectUsrInitString[];
EXTERN char APP_ReconnectCheckReconnect1String[];
EXTERN char APP_ReconnectCheckReconnect2String[];

EXTERN char APP_ReconnectSpecialLinkExistString[];
EXTERN char APP_ReconnectProfileNotReady1String[];
EXTERN char APP_ReconnectPdlFcdKeyString[];
EXTERN char APP_ReconnectActiveDiscPushToQueueString[];

EXTERN char APP_RMSetBdaddrAlreadyExistLogString[];
EXTERN char APP_RMSetBdaddrOKLogString[];
EXTERN char APP_RMSetScoDiscFailLogString[];
EXTERN char APP_RMSetBdaddrFailLogString[];
EXTERN char APP_RMClearLinkLogString[];
EXTERN char APP_RMClearHFPLinkLogString[];
EXTERN char APP_RMClearA2DPLinkLogString[];
EXTERN char APP_RMClearAVRCPLinkLogString[];
EXTERN char APP_RMSetServiceBdAddrString[];
EXTERN char APP_RMESDInfoString[];


EXTERN char APP_StatePreventAutoPwrOnLogString[];
EXTERN char APP_StateLoadStateLogString[];
EXTERN char APP_StatePassThruLogString[];
EXTERN char APP_StateGetTopStateLogString[];
EXTERN char APP_StateIsSetAppLinkString[];
EXTERN char APP_StateDefaultLinkString[];
EXTERN char APP_StateFakeOnStatusString1[];
EXTERN char APP_StateFakeOnStatusString2[];
EXTERN char APP_StateVpRtAliveLogString[];
EXTERN char APP_StateIsInChargerCaseString1[];
EXTERN char APP_StateConnectabilityString[];
EXTERN char APP_StateDiscoverabilityString[];

EXTERN char APP_CheckKeyPwrOnLowBatInvalidLogString[];
EXTERN char APP_CheckKeyInvalidReason1LogString[];

EXTERN char APP_HfpKeyATIsActiveLinkLogString[];

EXTERN char APP_SystemKeyReconnectMaxLinkLogString[];
EXTERN char APP_SystemKeyResetNameSucessLogString[];
EXTERN char APP_SystemKeyResetNameFailLogString[];
EXTERN char APP_SystemKeyAncOnFailLogString[];
EXTERN char APP_SystemKeyAncOffFailLogString[];
EXTERN char APP_SystemKeyFCDResetToFactoryLogString[];


EXTERN char APP_TestModeStatusLogString[];
EXTERN char APP_TestModeHandlerLogString[];

EXTERN char APP_ParingConnectableStateLogString[];
EXTERN char APP_ParingConDiscoverableStateLogString[];
EXTERN char APP_ParingNonStateLogString[];
EXTERN char APP_ParingNoMatchDiscoverModeLogString[];
EXTERN char APP_ParingNoMatchConnectModeLogString[];
EXTERN char APP_ParingSetConnDiscHnadlerLogString[];
EXTERN char APP_ParingSetConnDiscHnadlerLogString2[];

EXTERN char APP_PowerOnHandlerLogString[];
EXTERN char APP_PowerOnRHOIngStopStatusLogString[];

EXTERN char APP_PowerOffLoaderReasonLogString[];
EXTERN char APP_PowerOffTimeoutLogString[];
EXTERN char APP_PowerOffSystemOffLogString[];
EXTERN char APP_PowerOffNotFakeOffPowerLogString[];
EXTERN char APP_PowerOffIsDefaultRolePartnerSyncPwrKeyLogString[];;

EXTERN char APP_RaceCmdHandlerLogString[];
EXTERN char APP_RaceCmdFotaStartLogString[];
EXTERN char APP_RaceCmdFotaStopLogString[];
EXTERN char APP_RaceCmdFotaStopReconnectScoLogString[];

EXTERN char APP_RaceCmdANCGetStatusLogString[];
EXTERN char APP_RaceCmdANCSetGainLogString[];

EXTERN char APP_VolA2dpSaveHistoryRuntimeLogString[];
EXTERN char APP_VolA2dpSpkMuteByLinkLogString[];
EXTERN char APP_VolA2dpCycleVolUpLogString[];
EXTERN char APP_VolA2dpCycleVolDownLogString[];

EXTERN char APP_VolAiroThruSendVolToDspLogString[];
EXTERN char APP_VolAiroThruSetSoundLevelLogString[];

EXTERN char APP_VolLineInVolUpLogString[];
EXTERN char APP_VolLineInCycleVolUpLogString[];
EXTERN char APP_VolLineInReachMaxLogString[];
EXTERN char APP_VolLineInCycleVolDownLogString[];
EXTERN char APP_VolLineInReachMinLogString[];
EXTERN char APP_LineInClearAudioDevLogString[];

EXTERN char APP_VolMp3CycleVolUpLogString[];
EXTERN char APP_VolMp3CycleVolDownLogString[];

EXTERN char APP_VolScoMicSaveHistoryLogString[];
EXTERN char APP_VolScoMicMuteByLinkLogString[];
EXTERN char APP_VolScoMicCycleVolUpLogString[];
EXTERN char APP_VolScoMicCycleVolDownLogString[];
EXTERN char APP_VolScoMicSetMicMuteLogString[];

EXTERN char APP_VolScoSaveHistoryLogString[];
EXTERN char APP_VolScoMuteByLinkLogString[];
EXTERN char APP_VolScoCycleVolUpLogString[];
EXTERN char APP_VolScoCycleVolDownLogString[];
EXTERN char APP_VolScoSetSpkMuteLogString[];

EXTERN char APP_VolVpRtCycleVolUpLogString[];
EXTERN char APP_VolVpRtCycleVolDownLogString[];

EXTERN char APP_SystemBtInitCfmLogString[];
EXTERN char APP_SystemBtDeInitCfmLogString[];
EXTERN char APP_SystemWriteLocalNameCfmLogString[];
EXTERN char APP_SystemWriteClassDeviceCfmLogString[];
EXTERN char APP_SystemWriteEIRDataCfmLogString[];
EXTERN char APP_SystemACLOpenIndLogString[];
EXTERN char APP_SystemACLOpenFailLogString[];
EXTERN char APP_SystemACLCloseIndLogString[];
EXTERN char APP_SystemSmIoCapabilityLogString[];
EXTERN char APP_SystemSmPinCodeLogString[];
EXTERN char APP_SystemSmUserCfmReqLogString[];
EXTERN char APP_SystemSmUserPassKeyReqLogString[];
EXTERN char APP_SystemSmSetServiceCfgCfmLogString[];
EXTERN char APP_SystemSmDelAllAuthDeviceCfnLogString[];
EXTERN char APP_SystemSetSniffSubratingLogString[];
EXTERN char APP_SystemSetModeCfmLogString[];
EXTERN char APP_SystemGapReqStatusLogString[];
EXTERN char APP_SystemUnknownMsgLogString[];
EXTERN char APP_SystemZombieAudioDeviceLogString[];
EXTERN char APP_SystemMpTestModeLogString[];
EXTERN char APP_SystemSetSingleHSModeLogString[];
EXTERN char APP_SystemSingleHSModeEnableLogString[];
EXTERN char APP_SystemSingleHSModeDisableLogString[];
EXTERN char APP_SystemSetSingleHSModeStateLogString[];

EXTERN char APP_SystemSingleHSModeEndLogString[];
EXTERN char APP_SystemSingleHSSetRoleSuccLogString[];
EXTERN char APP_SystemSingleHSSetRoleFailLogString[];
EXTERN char APP_SystemSingleHSLeavingModeSuccLogString[];
EXTERN char APP_SystemSingleHSSingleHSModeStateLogString[] ;
EXTERN char APP_SystemSingleHSEnterSingleHeadsetModeLogString[];
EXTERN char APP_SystemSingleHSEnterSingleHeadsetModeFailedLogString[];
EXTERN char APP_SystemSingleHSExitHSModeStateLogString[];
EXTERN char APP_SystemSingleHSModeBackRoleFailedLogString[];
EXTERN char APP_SystemSingleHSRoleModeLeaveLogString[] ;
EXTERN char APP_SystemSingleHSSetRoleMode1LogString[];
EXTERN char APP_SystemSingleHSSetRoleMode2LogString[];
EXTERN char APP_SystemSingleHSRoleModeLeaveIndLogString[];
EXTERN char APP_SystemSingleHSRoleModeLeaveIndClearAllModeLogString[];
EXTERN char APP_SystemSingleHSRoleModeChangeIndLogString[];
EXTERN char APP_SystemSBTGapDUTCfmLogString[];

/*APP Sniff*/
EXTERN char APP_SniffDisableLogString[];
EXTERN char APP_SniffEnableLogString[];
EXTERN char APP_SniffCheckLogString[];

/*APP AirApp*/
EXTERN char APP_AirAppFotaReconnectLogString[];
EXTERN char APP_AirAppFotaDisReconnLogString[];
EXTERN char APP_AirAppDisConnSppLogString[];
EXTERN char APP_AirAppDisConnBleLogString[];
EXTERN char APP_AirAppHandlerInitCfmLogString[];
EXTERN char APP_AirAppHandlerConnIndLogString[];
EXTERN char APP_AirAppHandlerDisConnIndLogString[];
EXTERN char APP_AirAppHandlerDisConnCfmLogString[];
EXTERN char APP_AirAppHandlerStartServiceCfmLogString[];
EXTERN char APP_AirAppHandlerSetRandomAddrCfmLogString[];
EXTERN char APP_AirAppHandlerAdvParamCfmLogString[];
EXTERN char APP_AirAppAdvEnableReqLogString[];
EXTERN char APP_AirAppHandlerSetAdvDataCfmLogString[];
EXTERN char APP_AirAppHandlerExchangeMTULogString[];
EXTERN char APP_AirAppHandlerBleDisConnRspLogString[];

/*APP Link Key*/
EXTERN char APP_LinkKeyReadNormalHistoryFail[];
EXTERN char APP_LinkKeyReadAwsHistoryFail[];
EXTERN char APP_LinkKeyReadFcdHistoryFail[];
EXTERN char APP_LinkKeyReadMiscParaFail[];
EXTERN char APP_LinkKeySetHistorySoundLevel[];
EXTERN char APP_LinkKeyUpdateHistory[];

/* APP MCS Link Key */
EXTERN char APP_McsLinkKey_UpdateRemoteLinkKey_LogString[];
EXTERN char APP_McsLinkKey_AgentAddNormalLinkKey_LogString[];
EXTERN char APP_McsLinkKey_PartnerAddNormalLinkKey_LogString[];
EXTERN char APP_McsLinkKey_PartnerMoveLinkKeyToTop_LogString[];
EXTERN char APP_McsLinkKey_PartnerSendLinkKey_LogString[];
EXTERN char APP_McsLinkKey_AgentSendLinkKey_LogString[];
EXTERN char APP_McsLinkKey_GetAuthDeviceCfm_LogString[];
EXTERN char APP_McsLinkKey_AddAuthDeviceCfm_LogString[];
EXTERN char APP_McsLinkKey_GetLocalLinkKey_LogString[];
EXTERN char APP_McsLinkKey_SyncLinkKeyInd_LogString[];
EXTERN char APP_McsLinkKey_GetNullLinkKey_LogString[];
EXTERN char APP_McsLinkKey_SyncBleLinkKeyInd_LogString[];
EXTERN char APP_McsLinkKey_SyncAmaDataInd_LogString[];
EXTERN char APP_McsLinkKey_GetAuthListCfm_LogString[];
EXTERN char APP_McsLinkKey_AddAuthListCfm_LogString[];



/*APP MCSync*/
EXTERN char APP_MCSyncInquiryCancelCfm[];
EXTERN char APP_MCSyncWriteInquiryModeCfm[];
EXTERN char APP_MCSyncSystemInquiryResult[];
EXTERN char APP_MCSyncSystemInquiryStopInd[];
EXTERN char APP_MCSyncSystemWriteInquiryAccessCodeCfm[];
EXTERN char APP_MCSyncInquiryLIAC[];
EXTERN char APP_MCSyncReqInquiryStatusCfm[];
EXTERN char APP_MCSyncPairingExitState[];
EXTERN char APP_MCSyncInquiryResultBdAddr[];
EXTERN char APP_MCSyncCompareRSSIValue[];
EXTERN char APP_MCSyncStillInAWSState[];
EXTERN char APP_MCSyncDecideAgent[];
EXTERN char APP_MCSyncDecidePartner[];

EXTERN char APP_MCSyncAirPairingStartLog[] ;
EXTERN char APP_MCSyncAirPairingReleaseAGLog[];
EXTERN char APP_MCSyncAirPairingNoAGLog[];
EXTERN char APP_MCSyncAirPairingNoRoleModeLog[];
EXTERN char APP_MCSyncAirPairingAGDetachLog[];
EXTERN char APP_MCSyncAirPairingCfmStatusLog[];
EXTERN char APP_MCSyncAirPairingRoleModeLeaveLog[];

/*APP Connection*/
EXTERN char APP_ConnectSetConnectedLog[];
EXTERN char APP_ConnectConnectCfmLog[];
EXTERN char APP_ConnectDisConnectCfmLog[];
EXTERN char APP_ConnectRegisterCfmLog[];
EXTERN char APP_ConnectUndefineMsgLog[];
EXTERN char APP_ConnectNoLinkDetachLog[];
EXTERN char APP_ConnectAllProfileRegisteredLog[];
EXTERN char APP_ConnectNeedToRHODelayLog[];

/*APP HFP*/
EXTERN char APP_HFPDisConnCfmLogString[];
EXTERN char APP_HFPScoLinkTypeLogString[];
EXTERN char APP_HFPScoLinkType[][MAX_LOG_STRING];
EXTERN char APP_HFPScoDisIndErrorLogString1[];
EXTERN char APP_HFPScoConnIndErrorLogString1[];
EXTERN char APP_HFPScoConnIndErrorLogString2[];
EXTERN char APP_HFPScoConnIndAcceptLogString[];
EXTERN char APP_HFPCallerNumIndLogString[];
EXTERN char APP_HFPRingIndLogString[];
EXTERN char APP_HFPPlusVgsLogString[];
EXTERN char APP_HFPPlusVgmLogString[];
EXTERN char APP_HFPServiceFailLogString[];
EXTERN char APP_HFPCallFailLogString[] ;
EXTERN char APP_HFPCallSetupFailLogString[];
EXTERN char APP_HFPCallHeldFailLogString[];
EXTERN char APP_HFPSignalFailLogString[];
EXTERN char APP_HFPRoamFailLogString[];
EXTERN char APP_HFPBatchgFailLogString[];
EXTERN char APP_HFPAppleSiriLogString[];
EXTERN char APP_HFPMsgLogString[];
EXTERN char APP_HFPFillRHODataErrorLogString[];
EXTERN char APP_HFPAssignRHODataErrorLogString[];
EXTERN char APP_HFPScoRHONotAllowMsgNumLogString[];
EXTERN char APP_HFPImgMediaRHONotAllowMsgNumLogString[];

EXTERN char APP_HFPMsg[][MAX_LOG_STRING];
EXTERN char APP_HFPStartServiceLogString[];
EXTERN char APP_HFPImgCallerIDLogString[];
EXTERN char APP_HFPImgAudioVoiceLogString[];
EXTERN char APP_HFPScoHandlerLogString[];
EXTERN char APP_HFPScoHandle[][MAX_LOG_STRING];
EXTERN char APP_HFPScoConnCfmString1[];
EXTERN char APP_HFPScoConnCfmString2[];
EXTERN char APP_HFPScoConnCfmErrorString1[];
EXTERN char APP_HFPScoConnCfmAddLinkString1[];
EXTERN char APP_HFPScoConnCfmAddLinkString2[];
EXTERN char APP_HFPScoConnCfmAddLinkString3[];
EXTERN char APP_HFPScoA2dpStreamHandlerExist1String[];
EXTERN char APP_HFPScoA2dpStreamHandlerNotExist1String[];

/*APP A2DP*/
EXTERN char APP_A2dpStartServiceCfmLogString[];
EXTERN char APP_A2dpStopServiceCfmLogString[];
EXTERN char APP_A2dpSignalConnIndLogString[];
EXTERN char APP_A2dpSignalConnCfmLogString1[];
EXTERN char APP_A2dpSignalConnCfmLogString2[];
EXTERN char APP_A2dpSignalDisConnCfmLogString1[];
EXTERN char APP_A2dpSignalDisConnCfmLogString2[];
EXTERN char APP_A2dpMediaConnCfmLogString[];
EXTERN char APP_A2dpMediaDisConnCfmLogString1[];
EXTERN char APP_A2dpMediaDisConnCfmLogString2[];
EXTERN char APP_A2dpStartIndLogString[];
EXTERN char APP_A2dpIndLogString[];
EXTERN char APP_A2dpCeltLogString[];
EXTERN char APP_A2dpDspPlayLogString[];
EXTERN char APP_A2dpMediaCodecChgLogString[];
EXTERN char APP_A2dpCodecChgFunLogString[];
EXTERN char APP_A2dpCodecChgFunLogString1[];
EXTERN char APP_A2dpCodecChgFunLogString2[];
EXTERN char APP_A2dpFillRHODataErrorLogString1[];
EXTERN char APP_A2dpAssignRHODataErrorLogString2[];

EXTERN char APP_A2dpRegisterA2dpStartHandlerLogString[];
EXTERN char APP_A2dpSCOStreamHandlerNOTExistLogString[];

/*APP CAPTOUCH*/
EXTERN char APP_CapTouchInitString[];
EXTERN char APP_CapTouchCallbackResultString[];

/* APP VP/RT sync */

EXTERN char APP_VPRT_MasterLogString[];
EXTERN char APP_VPRT_MasterNOTSyncBeepStopString[];
EXTERN char APP_VPRT_VPRTPlayingTimerString[];
EXTERN char APP_VPRT_VPRTBeepTimerString[];
EXTERN char APP_VPRT_PlayingVpRtDPCCallbackString[];
EXTERN char APP_VPRT_StopVpRtDPCCallbackString[];	;
EXTERN char APP_VPRT_PlayingBeepCallbackString[];
EXTERN char APP_VPRT_SetOSDPCTimerString[];
EXTERN char APP_VPRT_SetOSDPCStopTimerString[];
EXTERN char APP_VPRT_SetSyncTimerSlave1String[];
EXTERN char APP_VPRT_SetSyncTimerSlave2String[];

/*APP AVRCP*/
EXTERN char APP_AvrcpPlayStatusLogString[];
EXTERN char APP_AvrcpDecideOpIdLogString[];
EXTERN char APP_AvrcpSendOpIdLogString[];
EXTERN char APP_AvrcpGetAbsVolLogString[];
EXTERN char APP_AvrcpPassThroughIndLogString[];
EXTERN char APP_AvrcpGetPlayStausIndogString[];
EXTERN char APP_AvrcpRegNotifyRspIndLogString[];
EXTERN char APP_AvrcpNotifyErrorLogString[];
EXTERN char APP_AvrcpRegNotifyRspEvtID[][MAX_LOG_STRING];
EXTERN char APP_AvrcpPassThroughRspIndLogString[];
EXTERN char APP_AvrcpIndHandleLogString[];
EXTERN char APP_AvrcpIndID[][MAX_LOG_STRING];
EXTERN char APP_AvrcpTimerLogString[];
EXTERN char APP_AvrcpTimerID[][MAX_LOG_STRING];

/*NvKey Handler*/
EXTERN char NvKeyHandler_SetStatus[];
EXTERN char NvKeyHandler_RmvStatus[];

/*USB*/
EXTERN char USB_EmmcInitFailLogString[];
EXTERN char USB_EmmcInitPassLogString[];
EXTERN char USB_SdcInitFailLogString[];
EXTERN char USB_SdcInitPassLogString[];
EXTERN char USB_MassStorageInitFailLogString[];

/* BT Lib log */

/* L2cap */
EXTERN char L2CAP_TimeOutHandlerString[];
EXTERN char L2CAP_HandleConReqString[];
EXTERN char L2CAP_SendAclDisconnIndString[];
EXTERN char L2CAP_Host_IpcMsgDispatchString[];
EXTERN char L2CAP_L2CAP_Sig_Send_RejString[];
EXTERN char L2CAP_Sig_Send_ConReqString[];
EXTERN char L2CAP_Sig_Send_ConRspString[];
EXTERN char L2CAP_Sig_Send_ConfigReqString[];
EXTERN char L2CAP_Sig_Send_ConfigRspString[];
EXTERN char L2CAP_Sig_Send_InfoRspString[];
EXTERN char L2CAP_Sig_Send_DisconnReqString[];
EXTERN char L2CAP_Sig_Send_DisconRspString[];
EXTERN char L2CAP_Sig_Send_EchoReqString[];
EXTERN char L2CAP_Sig_Send_EchoRspString[];
EXTERN char L2CAP_Sig_Send_InfoReqString[];
EXTERN char L2CAP_Sig_Send_ConnUpdateReqString[];
EXTERN char L2CAP_Sig_Send_ConnUpdateRspString[];
EXTERN char L2CAP_Sig_Handle_ConReq1String[];
EXTERN char L2CAP_Sig_Handle_ConRspString[];
EXTERN char L2CAP_Sig_Handle_ConRsp1String[];
EXTERN char L2CAP_Sig_Handle_ConfigReqString[];
EXTERN char L2CAP_Sig_Handle_DisconReqString[];
EXTERN char L2CAP_CheckStateString[];
EXTERN char L2CAP_CheckState1String[];
EXTERN char L2CAP_CheckState2String[];
EXTERN char L2CAP_CheckState3String[];
EXTERN char L2CAP_SignalingString[];
EXTERN char L2CAP_Sig_Handle_ConfigRspString[];
EXTERN char L2CAP_Sig_Handle_DisconRspString[];
EXTERN char L2CAP_Sig_Handle_InfoReqString[];
EXTERN char L2CAP_Sig_Handle_InfoRspString[];
EXTERN char L2CAP_Sig_Handle_EchoReqString[];
EXTERN char L2CAP_Sig_Handle_EchoRspString[];
EXTERN char L2CAP_Sig_Handle_ConnUpdateReqString[];
EXTERN char L2CAP_Sig_Handle_ConnUpdateRspString[];
EXTERN char SinkCloseL2capString[];
EXTERN char SourceCloseL2capString[];
EXTERN char SinkClaimL2capString[];
EXTERN char SinkClaimL2cap1String[];
EXTERN char SourceL2capSDUDispatchString[];
EXTERN char SourceL2capFeedString[];
EXTERN char SourceL2capFeed1String[];
EXTERN char SourceL2capFeed2String[];
EXTERN char StreamL2capSourceNewString[];
EXTERN char StreamL2capSinkNewString[];
EXTERN char BT_INTERNAL_L2CAP_CONNECT_REQString[];
EXTERN char BT_INTERNAL_L2CAP_CONNECT_REQ1String[];
EXTERN char BT_INTERNAL_L2CAP_CONNECT_REQ2String[];
EXTERN char BT_INTERNAL_L2CAP_CONNECT_REQ3String[];
EXTERN char L2CAP_ApplyAgentRhoData_String[];
EXTERN char L2CAP_ApplyAgentRhoData2_String[];
EXTERN char L2CAP_GetRhoData_String[];

/* Sdp  */
EXTERN char BtSdpOpenSearchRequestString[];
EXTERN char BtSdpCloseSearchRequestString[];
EXTERN char SdpClient_ResetChannelString[];
EXTERN char SdpClient_SendServiceSearchReqString[];
EXTERN char SdpClient_SendServiceAttributeReqString[];
EXTERN char SdpClient_SendServiceSearchAttributeReqString[];
EXTERN char SdpClient_HandleErrorRspString[];
EXTERN char SdpClient_HandleServiceSearchRspString[];
EXTERN char SdpClient_HandleServiceAttributeRspString[];
EXTERN char SdpClient_HandleServiceSearchAttributeRspString[];
EXTERN char SdpClient_HandleL2cConnectCfmString[];
EXTERN char SdpClient_HandleL2cDisconnectIndString[];
EXTERN char SdpClient_HandleL2cDisconnectCfmString[];
EXTERN char SDP_Client_L2capConnReqString[];
EXTERN char SDP_Client_L2capConnReq0String[];
EXTERN char SDP_Client_L2capConnReq1String[];
EXTERN char SDP_Client_L2capConnReq2String[];
EXTERN char SDP_Client_L2capConnReq3String[];
EXTERN char SDP_Client_L2capDisconnReqString[];
EXTERN char SDP_Client_L2capDisconnReq1String[];
EXTERN char SDP_Client_L2capDisconnReq2String[];
EXTERN char SDP_Client_L2capDisconnReq3String[];
EXTERN char SDP_Client_L2capDisconnReq4String[];
EXTERN char SDP_Client_L2capDisconnReq5String[];
EXTERN char SDP_Client_ServiceSearchString[];
EXTERN char SDP_Client_AttributeSearchString[];
EXTERN char SDP_Client_ServiceSearchAttributeString[];
EXTERN char SdpServer_SendErrorResponseString[];
EXTERN char SdpServer_HandleServiceSearchReqString[];
EXTERN char SdpServer_HandleServiceSearchReq1String[];
EXTERN char SdpServer_HandleServiceAttributeReqString[];
EXTERN char SdpServer_HandleServiceAttributeReq1String[];
EXTERN char SdpServer_HandleServiceSearchAttributeReqString[];
EXTERN char SdpServer_HandleServiceSearchAttributeReq1String[];
EXTERN char SdpServer_HandleL2cConnectIndString[];
EXTERN char SdpServer_HandleL2cConnectCfmString[];
EXTERN char SdpServer_HandleL2cDisconnectIndString[];
EXTERN char SdpServer_HandleL2cDisconnectCfmString[];
EXTERN char SdpServer_HandleL2cRegisterCfmString[];
EXTERN char SdpServer_HandleL2cUnregisterCfmString[];


/* Gap */

EXTERN char BtUtilGetTicketString[];
EXTERN char Gap_Link_SetAttr_SniffLockString[];
EXTERN char Gap_Link_SetAttr_DetachingString[];
EXTERN char Gap_Link_GetAttr_DetachingString[];
EXTERN char Gap_Link_SetAttr_ClearString[];
EXTERN char BT_INTERNAL_HCI_MODE_CHANGE_INDString[];
EXTERN char BT_INTERNAL_HCI_QOS_SETUP_COMPLETE_INDString[];
EXTERN char BT_INTERNAL_HCI_CMD_SEND_CFMString[];
EXTERN char BT_INTERNAL_HCI_CMD_SEND_CFM1String[];
EXTERN char BT_INTERNAL_SET_LINK_MODE_REQString[];
EXTERN char BT_INTERNAL_QOS_SETUP_REQString[];
EXTERN char BT_INTERNAL_HCI_CMD_SEND_CFMLinkString[];
EXTERN char BT_INTERNAL_HCI_CMD_SEND_CFMLink1String[];
EXTERN char BT_INTERNAL_GAP_PAGING_REQString[];
EXTERN char BT_INTERNAL_HCI_LINK_KEY_REQUEST_INDString[];
EXTERN char GAP_detach_LinkString[];
EXTERN char GAP_detach_Link1String[];
EXTERN char Security_DB_DeleteAllLinkKeyString[];
EXTERN char Security_DB_DeleteLinkKeyString[];
EXTERN char Security_DB_WriteLinkKeyString[];
EXTERN char BT_INTERNAL_HCI_CONNECT_COMPLETE_INDString[];
EXTERN char BT_INTERNAL_HCI_CONNECT_COMPLETE_IND1String[];
EXTERN char BT_INTERNAL_HCI_CONNECT_COMPLETE_IND2String[];
EXTERN char Gap_Link_SetAttr_StateString[];
EXTERN char Gap_ApplyAgentRhoData_String[];
EXTERN char Gap_GetIdxByConnHdl_String[];
EXTERN char Gap_RhoNotAllow1_String[];
EXTERN char Gap_RhoNotAllow2_String[];
EXTERN char Gap_RhoNotAllow3_String[];


/* Rfcomm */
EXTERN char BtRfcommRegisterChannelString[];
EXTERN char BtRfcommUnregisterChannelString[];
EXTERN char BtRfcommConnectRequestString[];
EXTERN char BtRfcommConnectResponseString[];
EXTERN char BtRfcommRemoteLineStatueRequestString[];
EXTERN char BtRfcommDisconnectRequestString[];
EXTERN char BtRfcommDisconnectResponseString[];
EXTERN char BT_INTERNAL_RFCOMM_CONNECT_REQString[];
EXTERN char RfcommSessionClearString[];
EXTERN char RfcommSessionSetStateString[];
EXTERN char RfcommDlciSetStateString[];
EXTERN char RfcommUtil_TimerSetString[];
EXTERN char RfcommUtil_TimerReleaseString[];
EXTERN char RfcommUtil_SendServerCfmString[];
EXTERN char RfcommUtil_ClearAllSessionDataString[];
EXTERN char RfcommHandlerString[];
EXTERN char RfcommHandler1String[];
EXTERN char RfcommHandler2String[];
EXTERN char RfcommHandler3String[];
EXTERN char RfcommHandler4String[];
EXTERN char RfcommFrame_HandleRemoteUIH_Dlci0String[];
EXTERN char RfcommFrame_HandleRemoteUIH_Dlci01String[];
EXTERN char RfcommFrame_HandleRemoteUIH_Dlci02String[];
EXTERN char RfcommFrame_HandleRemoteUIH_Dlci03String[];
EXTERN char RfcommFrame_HandleRemoteDMString[];
EXTERN char RfcommFrame_HandleRemoteDM1String[];
EXTERN char RfcommFrame_HandleRemoteDM2String[];
EXTERN char RfcommFrame_HandleMoreDataString[];
EXTERN char RfcommFrame_HandleMoreData1String[];
EXTERN char RfcommFrame_HandleMoreData2String[];
EXTERN char RfcommFrame_HandleMoreData3String[];
EXTERN char RfcommFrame_HandleMoreData4String[];
EXTERN char RrcommMuxCtl_HandlePNString[];
EXTERN char RrcommMuxCtl_HandleMSCString[];
EXTERN char RrcommMuxCtl_SendPNString[];
EXTERN char RfcommOp_OpenChannel_1_ProcessL2CAPString[];
EXTERN char RfcommOp_OpenChannel_1_ProcessL2CAP1String[];
EXTERN char RfcommOp_OpenChannel_2_ProcessDLCI0String[];
EXTERN char RfcommOp_OpenChannel_2_ProcessDLCI01String[];
EXTERN char RfcommOp_OpenChannel_3_ProcessDLCIString[];
EXTERN char RfcommOp_OpenChannel_3_ProcessDLCI1String[];
EXTERN char RfcommOp_OpenChannel_3_ProcessDLCI2String[];
EXTERN char RfcommOp_OpenChannel_3_ProcessDLCI3String[];
EXTERN char RfcommOp_OpenChannel_3_ProcessDLCI4String[];
EXTERN char RfcommOp_OpenChannel_3_ProcessDLCI5String[];
EXTERN char RfcommOp_GrantOpenChannelString[];
EXTERN char RfcommOp_GrantOpenChannel1String[];
EXTERN char StreamRfcommDlciCloseString[];
EXTERN char StreamRfcommSessionCloseString[];
EXTERN char StreamRfcommSinkNewString[];
EXTERN char StreamRfcommSourceNewString[];
EXTERN char SinkRfcommSetupString[];
EXTERN char SourceRfcommSetupString[];
EXTERN char RfcommSessionSetTxCreditString[];

EXTERN char Rfcomm_Dlci_state_String[][MAX_LOG_STRING];
EXTERN char Rfcomm_Session_state_String[][MAX_LOG_STRING];

EXTERN char L2capAirohaAirUpdateHandlerString[];
EXTERN char L2CAP_AirUpdateCloseStreamHandlerString[];

EXTERN char DebugRawDataPrintString[] ;
EXTERN char DebugRawDataPrint1String[];



EXTERN char RACE_CmdHandler_FOTA_commitString[];
EXTERN char RACE_CmdHandler_FOTA_commit1String[];
EXTERN char FotaResetHandlerString[];
EXTERN char RACE_CmdHandler_FOTA_QueryStateString[];
EXTERN char writeFotaStateString[];

/*lib AVCTP*/
EXTERN char AVCTP_INTERNAL_REG_REQ_STR1[];
EXTERN char AVCTP_INTERNAL_REG_REQ_STR2[];
EXTERN char AVCTP_INTERNAL_REG_REQ_STR3[];
EXTERN char AVCTP_INTERNAL_UNREG_REQ_STR1[];
EXTERN char AVCTP_INTERNAL_UNREG_REQ_STR2[];
EXTERN char AVCTP_INTERNAL_CONN_REQ_STR1[];
EXTERN char AVCTP_INTERNAL_CONN_REQ_STR2[];
EXTERN char AVCTP_INTERNAL_CONN_REQ_STR3[];
EXTERN char AVCTP_INTERNAL_CONN_RSP_STR1[];
EXTERN char AVCTP_INTERNAL_CONN_RSP_STR2[];
EXTERN char AVCTP_INTERNAL_CONN_RSP_STR3[];
EXTERN char AVCTP_INTERNAL_DISCONN_REQ_STR1[];
EXTERN char AVCTP_INTERNAL_DISCONN_REQ_STR2[];
EXTERN char AVCTP_INTERNAL_DISCONN_REQ_STR3[];
EXTERN char AVCTP_INTERNAL_DISCONN_REQ_STR4[];
EXTERN char AVCTP_INTERNAL_DISCONN_REQ_STR5[];
EXTERN char AVCTP_L2CAP_REG_CFM_STR1[];
EXTERN char AVCTP_L2CAP_REG_CFM_STR2[];
EXTERN char AVCTP_L2CAP_UNREG_CFM_STR[];
EXTERN char AVCTP_L2CAP_CONN_CFM_STR1[];
EXTERN char AVCTP_L2CAP_CONN_CFM_STR2[];
EXTERN char AVCTP_L2CAP_CONN_IND_STR1[];
EXTERN char AVCTP_L2CAP_CONN_IND_STR2[];
EXTERN char AVCTP_L2CAP_DISCONN_CFM_STR1[];
EXTERN char AVCTP_L2CAP_DISCONN_CFM_STR2[];
EXTERN char AVCTP_L2CAP_DISCONN_CFM_STR3[];
EXTERN char AVCTP_L2CAP_DISCONN_IND_STR1[];
EXTERN char AVCTP_DATA_SEND_SINGLE_PKT_STR[];
EXTERN char AVCTP_DATA_RECEIVE_SINGLE_PKT_STR[];
EXTERN char AVCTP_DATA_SINK_CLAIM_STR1[];
EXTERN char AVCTP_DATA_SINK_CLAIM_STR2[];
EXTERN char AVCTP_DATA_SINK_CLAIM_STR3[];
EXTERN char AVCTP_DATA_HANDLER_STR1[];
EXTERN char AVCTP_DATA_HANDLER_STR2[];
EXTERN char AVCTP_DATA_HANDLER_STR3[];
EXTERN char AVCTP_DATA_HANDLER_STR4[];
EXTERN char AVCTP_DATA_HANDLER_STR5[];

/* AVDTP */
EXTERN char AVDTP_REQ_String[];
EXTERN char AVDTP_IND_String[];
EXTERN char AVDTP_CFM_String[];

EXTERN char AVDTP_ConIndNone_String[];
EXTERN char AVDTP_ConIndMedia_String[];
EXTERN char AVDTP_ConIndReject_String[];


EXTERN char AVDTP_SendIND_String[];
EXTERN char AVDTP_SendCFM_String[];

EXTERN char AVDTP_Tx_CMD_String[];
EXTERN char AVDTP_Tx_RSP_Accept_String[];
EXTERN char AVDTP_Tx_RSP_Reject_String[];

EXTERN char AVDTP_Rx_CMD_String[];
EXTERN char AVDTP_Rx_RSP_Accept_String[];
EXTERN char AVDTP_Rx_RSP_Reject_String[];

EXTERN char AVDTP_REG_REQ_STR1[];
EXTERN char AVDTP_REG_REQ_STR2[];
EXTERN char AVDTP_UNREG_REQ_STR[];
EXTERN char AVDTP_MEDIA_CONN_REQ_STR[];
EXTERN char AVDTP_MEDIA_DISCONN_REQ_STR[];
EXTERN char AVDTP_MEDIA_CONN_CFM_STR[] ;

EXTERN char AVDTP_MEDIA_NO_SOURCE_STR[];
EXTERN char AVDTP_MEDIA_NO_LINK_STR[];
EXTERN char AVDTP_MEDIA_IS_MEDIA_PLAY_STR[];

EXTERN char AVDTP_REG_CFM_STR[];
EXTERN char AVDTP_SIGNAL_CONN_CFM_STR1[];
EXTERN char AVDTP_SIGNAL_CONN_CFM_STR2[];

EXTERN char AVDTP_SEND_FAIL_STR[];

EXTERN char AVDTP_ACCEPT_RSP_HEADER_STR[];
EXTERN char AVDTP_ACCEPT_REJ_HEADER_STR[];
EXTERN char AVDTP_RSP_ACCEPT_STR[];
EXTERN char AVDTP_CMD_STR[];
EXTERN char AVDTP_NO_SOURCE_STR[];
EXTERN char AVDTP_NO_PDU_STR[];
EXTERN char AVDTP_NO_LINK_INFO_STR[];
EXTERN char AVDTP_PDU_INFO_STR[];

/*Profile AVRCP*/
EXTERN char Avrcp_Opcode_String[][MAX_LOG_STRING];
EXTERN char AVRCP_DATA_HANDLER_STR1[];
EXTERN char AVRCP_DATA_HANDLER_STR2[];
EXTERN char AVRCP_DATA_HANDLER_STR3[];
EXTERN char AVRCP_RX_CMD_STR1[];
EXTERN char AVRCP_RX_CMD_STR2[];
EXTERN char AVRCP_RX_CMD_STR3[];
EXTERN char AVRCP_RX_CMD_STR4[];
EXTERN char AVRCP_RX_CMD_STR5[];
EXTERN char AVRCP_RX_RSP_STR1[];
EXTERN char AVRCP_RX_RSP_STR2[];
EXTERN char AVRCP_RX_RSP_STR3[];
EXTERN char AVRCP_PDU_ID_STR[][MAX_LOG_STRING];
EXTERN char AVRCP_OPID_STR[][MAX_LOG_STRING];
EXTERN char AVRCP_REG_CFM_STR[];
EXTERN char AVRCP_UNREG_CFM_STR[];
EXTERN char AVRCP_CONN_CFM_STR[];
EXTERN char AVRCP_DISCONN_CFM_STR[];
EXTERN char AVRCP_CONN_IND_STR[];
EXTERN char AVRCP_CONN_IND_CONFLICT_STR[];
EXTERN char AVRCP_CONN_IND_NORESOURCE_STR[];
EXTERN char AVRCP_SDP_REG_CFM_STR[];
EXTERN char AVRCP_SDP_UNREG_CFM_STR[];
EXTERN char AVRCP_SDP_OPEN_SEARCH_CFM_STR[];
EXTERN char AVRCP_SDP_CLOSE_SEARCH_CFM_STR[];
EXTERN char AVRCP_SDP_SERVICE_SEARCH_STR[];
EXTERN char AVRCP_SDP_ERROR_SRT1[];
EXTERN char AVRCP_SDP_ERROR_SRT2[];
EXTERN char AVRCP_SDP_ERROR_SRT3[];
EXTERN char AVRCP_TX_CMD_STR[];
EXTERN char AVRCP_TX_RSP_STR[];
EXTERN char AVRCP_TX_RESULT_STR[][MAX_LOG_STRING];
EXTERN char AVRCP_TX_CMD_RSP_STR[][MAX_LOG_STRING];

/*Profile HFP*/
EXTERN char HFP_TIMEOUT_LOG_STR[];
EXTERN char HFP_TIMER_STR[][MAX_LOG_STRING];
EXTERN char HSP_SDP_CFM_LOG_STR[];
EXTERN char HFP_SDP_CFM_LOG_STR[];
EXTERN char HFP_SDP_CFM_STR[][MAX_LOG_STRING];
EXTERN char HSP_SDP_CFM_STATUS_STR[];
EXTERN char HFP_SDP_CFM_STATUS_STR[];
EXTERN char HFP_RFCOMM_LOG_STR[];
EXTERN char HFP_RFCOMM_STR[][MAX_LOG_STRING];
EXTERN char HFP_RFCOMM_STATUS_STR[];
EXTERN char HFP_RFCOMM_NO_LINKINFO_STR[];
EXTERN char HFP_RFCOMM_ESTABLISH_SLC_STR[];
EXTERN char HFP_RFCOMM_CHANNEL[];
EXTERN char HSP_RFCOMM_CHANNEL[];
EXTERN char HFP_RFCOMM_CONN_IND_STR[];
EXTERN char HFP_RFCOMM_CONN_IND_CONFLICT_STR[];
EXTERN char HFP_RFCOMM_NO_RESOURCE_STR[];
EXTERN char HFP_RFCOMM_CONN_REQ_STR[];
EXTERN char HSP_RFCOMM_CONN_REQ_STR[];
EXTERN char HFP_REMOTE_BRSF_STR[];
EXTERN char HFP_CLEAR_LINK_STR[];
EXTERN char HFP_GET_TX_PTR_STR[];
EXTERN char HFP_REMOTE_CODEC_STR[];
EXTERN char HFP_SCO_CODEC_STR[][MAX_LOG_STRING];
EXTERN char HFP_PROFILE_STATE_LOG_STR[];
EXTERN char HFP_PROFILE_STATE_STR[][MAX_LOG_STRING];
EXTERN char HFP_SEND_AT_CMD_LOG_STR[];
EXTERN char HFP_CMD_STATE_LOG_STR[];
EXTERN char HFP_CMD_STATE_STR[][MAX_LOG_STRING];
EXTERN char HFP_RESULT_CODE_LOG_STR[];
EXTERN char HFP_RESULT_CODE_STR[][MAX_LOG_STRING];
EXTERN char HFP_PUSH_CMD_LOG_STR[];
EXTERN char HFP_INTERNAL_CMD_LOG_STR[];
EXTERN char HFP_PUSH_CMD_STR[][MAX_LOG_STRING];

EXTERN char A2DPStreamReadBufLogString[];
EXTERN char A2DPStreamDropLogString[];
EXTERN char A2DPStreamSBCErrorLogString[];
EXTERN char A2DPStreamSBCFrameErrorLogString[];
EXTERN char A2DPStreamSBCNoPacket[];
EXTERN char A2DPStreamAACNoPacket[];

EXTERN char PM_ClearInfoLogString[];
EXTERN char PM_NoProfileLoadLogString[];
EXTERN char PM_ActiveDiscProfileLogString[];
EXTERN char PM_BuildInProfileLogString[];
EXTERN char PM_EnterSniffModeLogString[];
EXTERN char PM_ExitSniffModeLogString[];
EXTERN char PM_SniffDelayTimerLogString[];
EXTERN char PM_CheckRemoteTimerLogString[];
EXTERN char PM_SniffDisableLogString[];
EXTERN char PM_SniffEnableLogString[];
EXTERN char PM_SetModeCfmLogString[];
EXTERN char PM_ModeChangeExitLogString[];
EXTERN char PM_LoadProfileLogString1[];
EXTERN char PM_LoadProfileLogString2[];
EXTERN char PM_LoadProfileLogString3[];
EXTERN char PM_ActivateProfileLogString1[];
EXTERN char PM_ActivateProfileLogString2[];
EXTERN char PM_SetLinkPolicyDisableLogString[];
EXTERN char PM_SetLinkPolicyEnableLogString[];
EXTERN char PM_ReconnectTimerHandlerString[];
EXTERN char PM_PushReconnectMissionString[];
EXTERN char PM_RhoActivateProfileErrorString1[];
EXTERN char PM_RhoActivateProfileErrorString2[];
EXTERN char PM_ProfileIdLoadString[];
EXTERN char PM_SetLinkStateLogString[];
EXTERN char PM_ConflictStateMachineLogString[];
EXTERN char PM_ConflictStateLogString[][MAX_LOG_STRING];
EXTERN char PM_ConflictEventLogString[][MAX_LOG_STRING];
EXTERN char PM_ConflictClearInfoLogString[];
EXTERN char PM_ConflictReconnectLogString[];
EXTERN char PM_RHOStartingSetReconnectAgainString[];



EXTERN char APP_LedSetRepeatLogStr[];
EXTERN char APP_LedSetAddTimeLogStr[];
EXTERN char APP_LedSetT4TimeLogStr[];
EXTERN char APP_LedHandlerLogStr[];
EXTERN char APP_LedSetT3TimeLogStr[];
EXTERN char APP_LedSetT4Time2LogStr[];
EXTERN char APP_LedSetRepeat2LogStr[];
EXTERN char APP_LedSetT4Time3LogStr[];
EXTERN char APP_LedResumeBGLogStr[];
EXTERN char APP_LedInitFailLogStr[];
EXTERN char APP_LedInitSuccessLogStr[];

EXTERN char APP_DSPA2dpNoSourceLogString[];
EXTERN char APP_DSPA2dpNoSinkLogString[];
EXTERN char APP_DSPA2dpSbcDecoderLogString[];
EXTERN char APP_DSPA2dpAacDecoderLogString[];
EXTERN char APP_DSPA2dpCeltDecoderLogString[];
EXTERN char APP_DSPA2dpCodecNotSupportLogString[];
EXTERN char APP_DSPA2dpNoTransformLogString[];
EXTERN char APP_DSPA2dpDspStopLogString[];
EXTERN char APP_DSPA2dpSourceTransformExistLogString[];
EXTERN char APP_DSPA2dpSinkTransformExistLogString[];
EXTERN char APP_DSPA2dpSampleRateCodecString[];
EXTERN char APP_DSPA2dpChannelSelNvkeyErrorLogString[];
EXTERN char APP_DSPA2dpChannelSelNvkeyValueLogString[];
EXTERN char APP_DSPA2dpSWChannelSetting[];
EXTERN char APP_DSPA2dpHWChannelSetting[];
EXTERN char APP_DSPA2dpNotMatchModeString[];
EXTERN char APP_DSPA2dpNotEnableChannelSelString[];
EXTERN char APP_DSPA2dpHWModeAudioChannelSettingString[];
EXTERN char APP_DSPA2dpSetAudioSelectString[];

EXTERN char APP_DSPA2dpFillRHODataErrorSetting[];
EXTERN char APP_DSPA2dAssignRHODataErrorSetting[];
EXTERN char APP_DSPA2dEnterA2dpStreamHandlerLogString[];
EXTERN char APP_DSPA2dcallSCOOpenHandlerLogString[];
EXTERN char APP_DSPScoEnterSCOStreamHandlerLogString[];
EXTERN char APP_DSPScoCallA2dpStartHandlerHandlerLogString[];
EXTERN char APP_DSPScoEnterSCOOpenHandlerLogString[];
EXTERN char APP_DSPA2dpSetPartnerInitWaitValueLogString[];
EXTERN char APP_DSPA2dpSetPartnerLaterJoinLogString1[];
EXTERN char APP_DSPA2dpSetPartnerLaterJoinLogString2[];
EXTERN char APP_DSPA2dpSetPartnerLaterJoinLogString3[];
EXTERN char APP_DSPA2dpOutOfSyncLogString[];
EXTERN char APP_DSPA2dpOutOfSyncReInitDoneLogString[];


EXTERN char APP_DSPMP3HaveFilesInDriveLogString[];
EXTERN char APP_DSPMP3NoFileInDriveLogString[];
EXTERN char APP_DSPMP3EmmcInitLogString[];
EXTERN char APP_DSPMP3SdcInitLogString[];
EXTERN char APP_DSPMP3F2ParentRootLogString[];
EXTERN char APP_DSPMP3F2ChildFailLogString[];
EXTERN char APP_DSPMP3FindEndFolderNoFolderLogString[];
EXTERN char APP_DSPMP3FindEndFolderUnknowErrorLogString[];
EXTERN char APP_DSPMP3FNextRootLogString[];
EXTERN char APP_DSPMP3FNextRoot2LogString[];
EXTERN char APP_DSPMP3FNextRoot3LogString[];
EXTERN char APP_DSPMP3FNextUnknowErrorLogString[];
EXTERN char APP_DSPMP3FPrevLogString[];
EXTERN char APP_DSPMP3FPrevAFolderExistLogString[];
EXTERN char APP_DSPMP3FPrevUnknowErrorLogString[];
EXTERN char APP_DSPMP3FindTrackErrorLogString[];
EXTERN char APP_DSPMP3NoMp3FileLogString[];
EXTERN char APP_DSPMP3FileSeekLogString[];
EXTERN char APP_DSPMP3OpenFileFailLogString[];
EXTERN char APP_DSPMP3FileMountLogString[];
EXTERN char APP_DSPMP3NoSourceLogString[];
EXTERN char APP_DSPMP3NoSinkLogString[];
EXTERN char APP_DSPMP3CreateStreamPauseLogString[];
EXTERN char APP_DSPMP3NoTransformLogString[];
EXTERN char APP_DSPMP3TransformOkLogString[];
EXTERN char APP_DSPMP3DspStopLogString[];
EXTERN char APP_DSPMP3SourceExistLogString[];
EXTERN char APP_DSPMP3SinkExistLogString[];
EXTERN char APP_DSPMP3NvkeyErrorLogString[];

EXTERN char APP_DSPRtSetEventFailPlayingLogString[];
EXTERN char APP_DSPRtSetEventFailNotFoundEvtTableLogString[];
EXTERN char APP_DSPRtSetEventFailNotFoundIdLogString[];
EXTERN char APP_DSPRtSetEventOkLogString[];
EXTERN char APP_DSPRtNoEventLogString[];
EXTERN char APP_DSPRtNoSourceLogString[];
EXTERN char APP_DSPRtNoSinkLogString[];
EXTERN char APP_DSPRtNoTransformLogString[];
EXTERN char APP_DSPRtTransformOkLogString[];
EXTERN char APP_DSPRtDspStopLogString[];
EXTERN char APP_DSPRtSourceTransformExistLogString[];
EXTERN char APP_DSPRtSinkTransformExistLogString[];
EXTERN char APP_DSPRtSourceEndLogString[];
EXTERN char APP_DSPRtSinkEndLogString[];

EXTERN char APP_DSPScoTxTransformCloseLogString[];
EXTERN char APP_DSPScoTxSourceTransformExistLogString[];
EXTERN char APP_DSPScoTxSinkTransformExistLogString[];
EXTERN char APP_DSPScoTxLightMonoModeOnLogString[];
EXTERN char APP_DSPScoTxNoSourceLogString[];
EXTERN char APP_DSPScoTxCvsdLogString[];
EXTERN char APP_DSPScoTxMsbcLogString[];
EXTERN char APP_DSPScoTxNoSinkLogString[];
EXTERN char APP_DSPScoTxNoTransformLogString[];
EXTERN char APP_DSPScoTxTransformOkLogString[];
EXTERN char APP_DSPScoRxTransformCloseLogString[];
EXTERN char APP_DSPScoRxSourceTransformExistLogString[];
EXTERN char APP_DSPScoRxSinkTransformExistLogString[];
EXTERN char APP_DSPScoRxNoSourceLogString[];
EXTERN char APP_DSPScoRxNoSinkLogString[];
EXTERN char APP_DSPScoRxCvsdLogString[];
EXTERN char APP_DSPScoRxMsbcLogString[];
EXTERN char APP_DSPScoRxNoTransformLogString[];
EXTERN char APP_DSPScoRxTransformOkLogString[];
EXTERN char APP_DSPScoErrorCodecLogString[];
EXTERN char APP_DSPScoRxSideToneEnableLogString[];
EXTERN char APP_DSPScoRxSideToneDisableLogString[];

EXTERN char APP_DSPSideToneExcessVolLogString[];
EXTERN char APP_DSPSideToneNoSourceLogString[];
EXTERN char APP_DSPSideToneNoSinkLogString[];
EXTERN char APP_DSPSideToneOnLogString[];
EXTERN char APP_DSPSideToneOffLogString[];
EXTERN char APP_DSPSideToneCloseDaLogString[];
EXTERN char APP_DSPSideToneCloseAdLogString[];

EXTERN char APP_DSPVcPathExistLogString[];
EXTERN char APP_DSPVcNoSourceLogString[];
EXTERN char APP_DSPVcNoSinkLogString[];
EXTERN char APP_DSPVcPathNotExistLogString[];
EXTERN char APP_DSPVcTransformOkLogString[];
EXTERN char APP_DSPVcTransformNotOkLogString[];
EXTERN char APP_DSPVcTransformHasExistedLogString[];
EXTERN char APP_DSPVcSourceTransformExistLogString[];
EXTERN char APP_DSPVcSinkTransformExistLogString[];

EXTERN char APP_DSPVpSetEventFailPlayingLogString[];
EXTERN char APP_DSPVpSetEventFailNoLangLogString[];
EXTERN char APP_DSPVpSetEventFailNoIdLogString[];
EXTERN char APP_DSPVpSetEventOkLogString[];
EXTERN char APP_DSPVpGetFileIdNoteLogString[];
EXTERN char APP_DSPVpGetFileIdLogString[];
EXTERN char APP_DSPVpNoFileIdTableLogString[];
EXTERN char APP_DSPVpEventEndLogString[];
EXTERN char APP_DSPVpNoThisFileLogString[];
EXTERN char APP_DSPVpNoSourceLogString[];
EXTERN char APP_DSPVpNoSinkLogString[];
EXTERN char APP_DSPVpNoTransformLogString[];
EXTERN char APP_DSPVpTransformOkLogString[];
EXTERN char APP_DSPVpNextEndLogString[];
EXTERN char APP_DSPVpNextErrorLogString[];
EXTERN char APP_DSPVpNextNoFileLogString[];
EXTERN char APP_DSPVpNextOkLogString[];
EXTERN char APP_DSPVpDspStopLogString[];
EXTERN char APP_DSPVpSourceTransformExistLogString[];
EXTERN char APP_DSPVpSinkTransformExistLogString[];
EXTERN char APP_DSPVpSourceEndLogString[];
EXTERN char APP_DSPVpSinkEndLogString[];
EXTERN char APP_DSPVpInitFailLogString[];

/* APP AUDIO BIST*/
EXTERN char APP_AudioBist_SilenceStartLogString[];
EXTERN char APP_AudioBist_SilenceStopLogString[];
EXTERN char APP_AudioBist_ResultPassString[];
EXTERN char APP_AudioBist_ResultFailLogString[];
EXTERN char APP_AudioBist_ADDANoSourceLogString[];
EXTERN char APP_AudioBist_ADDANoSinkLogString[];
EXTERN char APP_AudioBist_ADDANoTransformLogString[];
EXTERN char APP_AudioBist_ADDATransformOKLogString[];
EXTERN char APP_AudioBist_ADDATransformExistedLogString[];
EXTERN char APP_AudioBist_I2STransformExistedLogString[];
EXTERN char APP_AudioBist_I2SRoleErrorLogString[];
EXTERN char APP_AudioBist_I2SNoSourceLogString[];
EXTERN char APP_AudioBist_I2SNoSinkLogString[];
EXTERN char APP_AudioBist_I2SNoTransformLogString[];
EXTERN char APP_AudioBist_I2STransformOKLogString[];
EXTERN char APP_AudioBist_SPDIFTransformExistedLogString[];
EXTERN char APP_AudioBist_SPDIFNoSourceLogString[];
EXTERN char APP_AudioBist_SPDIFNoSinkLogString[];
EXTERN char APP_AudioBist_SPDIFTransformOKLogString[];
EXTERN char APP_AudioBist_SPDIFNoTransformLogString[];
EXTERN char APP_AudioBist_CPBistInvalidModeLogString[];
EXTERN char APP_AudioBist_CPBistStartLogString[];
EXTERN char APP_AudioBist_CPBistForceStopLogString[];
EXTERN char APP_AudioBist_CPBistStopLogString[];
EXTERN char APP_AudioBist_hiiiiiiiiiiiiLogString[];
EXTERN char APP_AudioBist_CPBistTimeoutLogString[];
EXTERN char APP_AudioBist_CPBistTestLogString[];
EXTERN char APP_AudioBist_ThresholdSNPLogString[];
EXTERN char APP_AudioBist_BistResultLogString[];


/* APP Audio MIC Test*/
EXTERN char APP_AudioMic_NoMicToSpkTransformLogString[];
EXTERN char APP_AudioMic_MictoSpkExistedLogString[];
EXTERN char APP_AudioMic_MictoSpkNoSourceLogString[];
EXTERN char APP_AudioMic_MictoSpkNoSinkLogString[] ;
EXTERN char APP_AudioMic_MictoSpkNoTransLogString[];
EXTERN char APP_AudioMic_MictoSpkTransOKLogString[] ;
EXTERN char APP_AudioMic_MictoSpkTransCloseLogString[];
EXTERN char APP_AudioMic_MictoSpkSourceSinkCloseLogString[];
EXTERN char APP_DSPAmaAudioPathInitFailLogString[];
EXTERN char APP_DSPAmaAudioPathParaLogString[];
EXTERN char APP_DSPAmaAudioSourceSinkExistLogString[];
EXTERN char APP_DSPAmaStreamStartLogString[];
EXTERN char APP_DSPAmaStreamStopLogString[];
EXTERN char APP_DSPAma2MicEnableLogString[];
EXTERN char APP_DSPAma1MicEnableLogString[];






EXTERN char A2DP_Rx_CMD_String[];
EXTERN char A2DP_Tx_RSP_Accept_String[];
EXTERN char A2DP_Tx_RSP_Reject_String[];
EXTERN char A2DP_Rx_RSP_Accept_String[];
EXTERN char A2DP_Rx_RSP_Reject_String[];

EXTERN char A2DP_Tx_Discover_Data_String[];
EXTERN char A2DP_Tx_GetCap_Data_String[];
EXTERN char A2DP_Tx_SetConfig_Data_String[];
EXTERN char A2DP_Tx_GetConfig_Data_String[];
EXTERN char A2DP_Tx_Reconfig_Data_String[];
EXTERN char A2DP_Tx_CMD_String[];
EXTERN char A2DP_CODEC_String[];
EXTERN char A2DP_SBC_String[];
EXTERN char A2DP_AAC_String[];
EXTERN char A2DP_CELT_String[];
EXTERN char A2DP_Vendor_String[];
EXTERN char A2DP_SCMS_String[];
EXTERN char A2DP_SCMS_String[];
EXTERN char A2DP_REQ_String[];
EXTERN char A2DP_IND_String[];
EXTERN char A2DP_CFM_String[];
EXTERN char A2DP_RSP_String[];
EXTERN char A2DP_StateSubState_String[];
EXTERN char A2DP_EstMediaChannelTime_String[];
EXTERN char A2DP_IsMediaPlay_String[];
EXTERN char A2DP_DiscoverCmdPara_String[];
EXTERN char A2DP_CommonTimeOut_String[];
EXTERN char A2DP_SEID_String[];
EXTERN char A2DP_GetCapaCmdPara_String[];
EXTERN char A2DP_SetConfig_String[];
EXTERN char A2DP_GetConfigSize_String[];
EXTERN char A2DP_GetConfigData_String[];
EXTERN char A2DP_SetMediaPlay_String[];
EXTERN char A2DP_GetAACInfo_String[];
EXTERN char A2DP_GetSBCInfo_String[];

EXTERN char Connect_String[];
EXTERN char Disconnect_String[];
EXTERN char MediaConnect_String[];
EXTERN char MediaDisconnect_String[];
EXTERN char Register_String[];
EXTERN char UnRegister_String[];
EXTERN char NoApp_String[];
EXTERN char NoResource_String[];
EXTERN char Success_String[];
EXTERN char Conflict_String[];
EXTERN char AppReject_String[];
EXTERN char Unknown_ID_String[];
EXTERN char Accept_ID_String[];
EXTERN char AVDTP_SignalIDString[14][MAX_LOG_STRING];

/* MCSync */
EXTERN char MCSync_IFhandler_String[];
EXTERN char MCSync_IFType_String[][MAX_LOG_STRING];
EXTERN char MCSYNC_SendIFPkt_StartString[];
EXTERN char MCSYNC_SendIFPkt_ErrorString1[];
EXTERN char MCSYNC_SendIFPkt_ErrorString2[];
EXTERN char MCSync_IFPkt_APP_LogString[];
EXTERN char MCSYNC_SendIFPkt_AACCodecSetting[];
EXTERN char MCSYNC_SendIFPkt_SBCCodecSetting[];
EXTERN char MCSYNC_SendIFPkt_SyncSCO[];
EXTERN char MCSYNC_SendIFPkt_SyncLED1[];
EXTERN char MCSYNC_SendIFPkt_SyncLED3[];
EXTERN char MCSYNC_SendIFPkt_SyncDSP1[];
EXTERN char MCSYNC_SendIFPkt_SyncDSP2[];
EXTERN char MCSYNC_SendIFPkt_SyncCallerID[];
EXTERN char MCSYNC_SendIFPkt_SyncCallerInfo[];
EXTERN char MCSYNC_SendIFPkt_SyncA2DP[];
EXTERN char MCSYNC_SendIFPkt_SyncSBCCodecType[];
EXTERN char MCSYNC_SendIFPkt_SyncAACCodecType[];
EXTERN char MCSync_IF_AppOpcode_String[][MAX_LOG_STRING];

EXTERN char MCSync_SYNC_A2DP_String1[];
EXTERN char MCSync_SYNC_A2DP_String2[];
EXTERN char MCSync_SYNC_A2DP_String3[];
EXTERN char MCSync_SYNC_A2DP_AAC_SampleRate_String[];
EXTERN char MCSync_SYNC_A2DP_SBC_SampleRate_String[];
EXTERN char MCSync_SYNC_SCO_String[] ;
EXTERN char MCSync_SYNC_AgentState_String[];
EXTERN char MCSync_SYNC_SmartChargeCaseState_String[];
EXTERN char MCSync_SYNC_RhoState_String[];
EXTERN char MCSync_SYNC_ClientKeyCode_String[];
EXTERN char MCSync_SYNC_ANC_String[];
EXTERN char MCSync_SYNC_Airothru_String[];
EXTERN char MCSync_SYNC_LED_String1[];
EXTERN char MCSync_SYNC_LED_String2[];
EXTERN char MCSync_SYNC_AGNUM_String[];
EXTERN char MCSync_SYNC_VPRT_String1[];
EXTERN char MCSync_SYNC_VPRT_String2[];
EXTERN char MCSync_SYNC_DSP_String1[];
EXTERN char MCSync_SYNC_DSP_String2[];
EXTERN char MCSync_SYNC_RHO_PARA_String[];
EXTERN char MCSync_SYNC_VPRT_DelayIndString1[];
EXTERN char MCSync_SYNC_VPRT_DelayIndString2[];
EXTERN char MCSync_SendIFPkt_SyncPowerOff[];
EXTERN char MCSync_GetNormalLinkString[];
EXTERN char MCSync_GetSpecialLinkString[];
EXTERN char MCSync_GetNullLinkString[];
EXTERN char MCSYNC_SendIFPkt_SyncVPRT[];
EXTERN char MCSync_SlaveGetSyncVpRtIndexString[];
EXTERN char MCSync_SlaveGetSyncInfoString[];
EXTERN char MCSync_PartnerGetCallerIDLengthString[];
EXTERN char MCSync_PartnerGetCallerIDNumberString[];
EXTERN char MCSync_AgentSendCallerIDNumberString[];
EXTERN char MCSync_CallerIdAddrString[];
EXTERN char MCSYNC_SendIFPkt_SyncLinkList[];
EXTERN char MCSYNC_SendIFPkt_SyncBleLinkList[];
EXTERN char MCSYNC_SendIFPkt_SyncAmaData[];
EXTERN char MCSYNC_SendIFPkt_SyncReconnectState[];
EXTERN char MCSYNC_SendIFPkt_SyncReconnectMask[];
EXTERN char MCSync_RHO_NVKEY_INIT_FAIL_String[];
EXTERN char MCSync_RHO_DOMN_HANDLER_String[];
EXTERN char MCSync_RHO_DOMN_PARA_String[];
EXTERN char MCSync_RHO_NEEDED_PARA_String1[];
EXTERN char MCSync_RHO_NEEDED_PARA_String2[];
EXTERN char MCSync_RHO_NEEDED_RESULT_String[];
EXTERN char MCSync_SYNC_VPRT_PlayLaterInd[];
EXTERN char MCSync_SYNC_VPRT_PlayLater[];
EXTERN char MCSync_SYNC_SCOEvtIndA2dpStreamHandlerExist_String[];
EXTERN char MCSync_SYNC_SCOEvtIndA2dpStreamHandlerNotExist_String[];

EXTERN char MCSync_RHO_STATUS_String[][MAX_LOG_STRING];
EXTERN char MCSync_RHO_REASON_String[][MAX_LOG_STRING];
EXTERN char MCSync_RHO_NEEDED_FOR_POWEROFF_String[];
EXTERN char MCSync_RHO_NEEDED_FOR_CHARGIN_CASE_String[];
EXTERN char MCSync_IdleTimerCtlString[];
EXTERN char MCSync_SYNCPoweroffToPartnerString[];
EXTERN char MCSync_SetAWSIdleTimerString[];
EXTERN char MCSync_AwsIdleTimerString[];
EXTERN char MCSync_SyncKeyEventString[];
EXTERN char MCSync_SPConnectedCfmCancelIdleTimerString[];
EXTERN char MCSync_SPDisconnectedSetIdleTimerString[];
EXTERN char MCSync_PartnerDisconnectedCancelIdleTimerString[];
EXTERN char MCSync_PartnerConnectedSetIdleTimerString[];
EXTERN char MCSync_SyncAgentPowerOffString[];
EXTERN char MCSync_KeyEvent_Slink_String[];
EXTERN char MCSync_SyncKeyEventIsNotPartner[];
EXTERN char MCSync_NotSyncPowerOffString[];
EXTERN char MCSync_PairingInitState[];
EXTERN char MCSync_AppAwsRHONotAllowMsgNumberString[];
EXTERN char MCSync_AppAwsRHOFillDataFailString[];
EXTERN char MCSync_AppAwsRHOAssignDataFailString[];
EXTERN char MCSync_AppAwsDecideRoleString1[];
EXTERN char MCSync_AppAwsDecideRoleString2[];
EXTERN char MCSync_AppAwsDecideRoleString3[];
EXTERN char MCSync_APP_RoleModeChangeCfm_String[];
EXTERN char MCSync_APP_ReconnectStateInd_String[];
EXTERN char MCSync_APP_ReconnectMaskInd_String[];

/* MCSync Profile*/
EXTERN char MCSync_RegisterCfm_String[];
EXTERN char MCSync_ConnectCfm_String[];
EXTERN char MCSync_StatusChangeInd_String[];
EXTERN char MCSync_StatusChangeInd_StringFail[];
EXTERN char MCSync_EnableDiscoverable_String[];
EXTERN char MCSync_DisconnectInd_String[];
EXTERN char MCSync_SetRoleCfm_String[];
EXTERN char MCSync_GetCurrentPicoClockCfm_String[];
EXTERN char MCSync_RoleChangeInd_String[];
EXTERN char MCSync_ReadAFHCfm_String[];
EXTERN char MCSync_WriteLocalBdAddrCfm_String[];
EXTERN char MCSync_WriteLocalBdAddr_String[];
EXTERN char MCSync_WriteLocalBdAddr_String2[];
EXTERN char MCSync_GapHandlerUndefinedId_String[];
EXTERN char MCSync_ConnectCfmHandlerAssertString1[];
EXTERN char MCSync_ConnectCfmHandlerAssertString2[];
EXTERN char MCSync_ConnectCfmHandlerAssertString3[];
EXTERN char MCSync_CancelConnectionString[];
EXTERN char MCSync_DisconnectMCSyncProfileString[];
EXTERN char MCSync_DirectlySetBdAddrString[];
EXTERN char MCSync_DisconnectSpecialLinkString[];
EXTERN char MCSync_SetSingleHeadSetModeStateLogString[];
EXTERN char MCSync_CancelConnectionCfmLogString[];
EXTERN char MCSync_IsAbleToConnectAwsLinkNotAllowLogString1[];
EXTERN char MCSync_IsAbleToConnectAwsLinkNotAllowLogString2[];
EXTERN char MCSync_IsAbleToConnectAwsLinkNotAllowLogString3[];
EXTERN char MCSync_SetMcsyncStateLogString[];
EXTERN char MCSync_ActivateProfileLogString[];
EXTERN char MCSync_ActivateProfileLogString2[];
EXTERN char MCSync_PartnerModeRoleChanging_String[];
EXTERN char MCSync_PartnerModeStateNotNone_String[];
EXTERN char MCSync_PartnerModeNotAgent_String[];
EXTERN char MCSync_PartnerModeNoPartnerBdAddr_String[];
EXTERN char MCSync_PartnerModeAgNotDisconnected_String[];
EXTERN char MCSync_PartnerModeMCSyncConnected_String[];
EXTERN char MCSync_PartnerModeChangeStart_String[];
EXTERN char MCSync_AgentModeRoleChanging_String[];
EXTERN char MCSync_AgentModeStateNotNone_String[];
EXTERN char MCSync_AgentModeNotPartner_String[];
EXTERN char MCSync_AgentModeNoAgentBdAddr_String[];
EXTERN char MCSync_AgentModeAgNotDisconnected_String[];
EXTERN char MCSync_AgentModeMCSyncConnected_String[];
EXTERN char MCSync_AgentModeChangeStart_String[];
EXTERN char MCSync_NvKeyInit_String[];
EXTERN char MCSync_NvKeyInit_String2[];

/* APP RHO */
EXTERN char APP_RHO_InitLogString[];
EXTERN char APP_RHO_GetNextActionReachEndLogString[];
EXTERN char APP_RHO_ClearTxPacketLogString[];
EXTERN char APP_RHO_ClearRxPacketLogString[];
EXTERN char APP_RHO_FlowErrorLogString[];
EXTERN char APP_RHO_NotAllowLogString[];
EXTERN char APP_RHO_LockFailedLogString[];
EXTERN char APP_RHO_UnlockFailedLogString[];
EXTERN char APP_RHO_NewAgentDoneLogString[];
EXTERN char APP_RHO_CheckActionRelatedToRHOLogString[];
EXTERN char APP_RHO_PowerOffAfterRhoLogString[];
EXTERN char APP_RHO_DeepSleepAfterRhoLogString[];
EXTERN char APP_RHO_PowerOffChargerCaseLogString[];
EXTERN char APP_RHO_ApplyPartnerDataLogString[];
EXTERN char APP_RHO_ApplyAgentDataLogString[];
EXTERN char APP_RHO_ApplyDataFailedLogString[];
EXTERN char APP_RHO_ApplyDataModuleLogString[];
EXTERN char APP_RHO_ApplyDataWarningLogString[];
EXTERN char APP_RHO_CheckFotaLogString[];
EXTERN char APP_RHO_CheckRoleLogString[];
EXTERN char APP_RHO_CheckAgNumLogString[];
EXTERN char APP_RHO_CheckFlowLogString[];
EXTERN char APP_RHO_CheckAgLinkLogString[];
EXTERN char APP_RHO_CheckAgNoLinkLogString[];
EXTERN char APP_RHO_SetRhoFinishOkLogString[];
EXTERN char APP_RHO_SetRhoFinishFailedLogString[];
EXTERN char APP_RHO_CancelRhoCfmRetryLogString[];
EXTERN char APP_RHO_CancelRhoCfmStopRetryLogString[];
EXTERN char APP_RHO_CancelRhoCfmFailedLogString[];
EXTERN char APP_RHO_FlowWaitHandlerLogString[];
EXTERN char APP_RHO_IsAllowRetryLogString[];
EXTERN char APP_RHO_IsAllowRetryStopLogString[];
EXTERN char APP_RHO_LockStopPrepareLogString[];
EXTERN char APP_RHO_GetDataLengthLogString[];
EXTERN char APP_RHO_GetDataTotalSizeLogString[];
EXTERN char APP_RHO_GetDataNoMemLogString[];
EXTERN char APP_RHO_GetDataFailedLogString[];
EXTERN char APP_RHO_GetDataWarningLogString[];
EXTERN char APP_RHO_SendRhoPacketLogString[];
EXTERN char APP_RHO_SendRhoPacketNullLogString[];
EXTERN char APP_RHO_ActionFlowLogString[];
EXTERN char APP_RHO_ActionFlowWaitLogString[];
EXTERN char APP_RHO_ActionFlowErrorLogString[];
EXTERN char APP_RHO_FlowProcessLogString[];
EXTERN char APP_RHO_FlowProcessNextLogString[];
EXTERN char APP_RHO_CurrentRoleNoneLogString[];
EXTERN char APP_RHO_CurrentRolePartnerLogString[];
EXTERN char APP_RHO_CurrentRoleAgentLogString[];
EXTERN char APP_RHO_CurrentRoleUnknownLogString[];
EXTERN char APP_RHO_CfmTimeoutLogString[];
EXTERN char APP_RHO_StartLogString[];
EXTERN char APP_RHO_RecordRxPacketLogString[];
EXTERN char APP_RHO_RecordRxPacketNoAgentLogString[];
EXTERN char APP_RHO_RoleChangeIndToPartnerLogString[];
EXTERN char APP_RHO_AgentChangeToPartnerOkLogString[];
EXTERN char APP_RHO_RoleChangeIndToAgnetLogString[];
EXTERN char APP_RHO_PartnerChangeToAgentOkLogString[];
EXTERN char APP_RHO_SetStateLogString[];
EXTERN char APP_RHO_SetStartClockLogString[];
EXTERN char APP_RHO_SetEndClockLogString[];
EXTERN char APP_RHO_TimeCalculateErrorLogString[];
EXTERN char APP_RHO_PartnerDoneLogString[];
EXTERN char APP_RHO_ForceStopLogString[];

EXTERN char APP_RHO_MODULE_String[][MAX_LOG_STRING];
EXTERN char APP_RHO_RM_PartnerConfigLogString[];
EXTERN char APP_RHO_RM_PartnerConfigNoLinkLogString[];
EXTERN char APP_RHO_RM_IsAllowLogString[];
EXTERN char APP_RHO_RM_AssignDataLogString[];
EXTERN char APP_RHO_RM_AssignDataErrorLogString[];
EXTERN char APP_RHO_RM_AssignDataMemErrorLogString[];
EXTERN char APP_RHO_RM_FillDataOkLogString[];
EXTERN char APP_RHO_RM_FillDataErrorLogString[];
EXTERN char APP_RHO_RM_FillDataMemErrorLogString[];
EXTERN char APP_RHO_RM_AssignErrorLogString[];
EXTERN char APP_RHO_RM_FillErrorLogString[];
EXTERN char APP_RHO_RM_ScoSinkErrorLogString[];
EXTERN char APP_RHO_RM_ScoSinkLogString[];
EXTERN char APP_RHO_RM_LinkInfoNoLinkLogString[];
EXTERN char APP_RHO_RM_LinkInfoNoDataLogString[];
EXTERN char APP_RHO_RM_LinkInfoStateErrorLogString[];
EXTERN char APP_RHO_RM_LinkInfoFillNoLinkLogString[];
EXTERN char APP_RHO_RM_LinkInfoFillNoDataLogString[];
EXTERN char APP_RHO_RM_CtlAssignNoDataLogString[];
EXTERN char APP_RHO_RM_CtlFillNoDataLogString[];

/* AVCTP RHO */
EXTERN char MCSync_AVCTP_APPLY_PARTNER_String[];
EXTERN char MCSync_AVCTP_APPLY_AGENT_String1[];
EXTERN char MCSync_AVCTP_APPLY_AGENT_String2[];
EXTERN char MCSync_AVCTP_APPLY_AGENT_String3[];
EXTERN char MCSync_AVCTP_AGENT_GETDATA_String1[];
EXTERN char MCSync_AVCTP_AGENT_GETDATA_String2[];
EXTERN char MCSync_AVCTP_AGENT_GETDATA_String3[];
EXTERN char MCSync_AVCTP_AGENT_GETDATA_String4[];
EXTERN char MCSync_AVCTP_AGENT_RECORDMSG_String1[];
EXTERN char MCSync_AVCTP_AGENT_RECORDMSG_String2[];
EXTERN char MCSync_AVCTP_AGENT_RECORDMSG_String3[];
EXTERN char MCSync_AVCTP_AGENT_RECORDMSG_String4[];

/* AVDTP RHO */
EXTERN char MCSync_AVDTP_APPLY_PARTNER_String[];
EXTERN char MCSync_AVDTP_APPLY_AGENT_String1[];
EXTERN char MCSync_AVDTP_APPLY_AGENT_String2[];
EXTERN char MCSync_AVDTP_APPLY_AGENT_String3[];
EXTERN char MCSync_AVDTP_AGENT_GETDATA_String1[];
EXTERN char MCSync_AVDTP_AGENT_GETDATA_String2[];
EXTERN char MCSync_AVDTP_AGENT_GETDATA_String3[];
EXTERN char MCSync_AVDTP_AGENT_GETDATA_String4[];
EXTERN char MCSync_AVDTP_AGENT_RECORDMSG_String1[];
EXTERN char MCSync_AVDTP_AGENT_RECORDMSG_String2[];
EXTERN char MCSync_AVDTP_AGENT_RECORDMSG_String3[];
EXTERN char MCSync_AVDTP_AGENT_RECORDMSG_String4[];

/* A2DP RHO */
EXTERN char MCSync_A2DP_NEWAGENT_ASSIGN_String1[];
EXTERN char MCSync_A2DP_NEWAGENT_ASSIGN_String2[];
EXTERN char MCSync_A2DP_OLDAGENT_FILL_String1[];
EXTERN char MCSync_A2DP_OLDAGENT_FILL_String2[];
EXTERN char MCSync_A2DP_NEWPARTNER_APPLY_String[];
EXTERN char MCSync_A2DP_NEWAGENT_APPLY_String[];
EXTERN char MCSync_A2DP_NEWAGENT_APPLY_ERROR_String1[];
EXTERN char MCSync_A2DP_NEWAGENT_APPLY_ERROR_String2[];
EXTERN char MCSync_A2DP_NEWAGENT_APPLY_ERROR_String3[];
EXTERN char MCSync_A2DP_NEWAGENT_APPLY_SUCCESS_String[];
EXTERN char MCSync_A2DP_OLDAGENT_GETDATA_ERROR_String1[];
EXTERN char MCSync_A2DP_OLDAGENT_GETDATA_ERROR_String2[];
EXTERN char MCSync_A2DP_OLDAGENT_GETDATA_ERROR_String3[];
EXTERN char MCSync_A2DP_OLDAGENT_GETDATA_POPQ_String[];
EXTERN char MCSync_A2DP_OLDAGENT_GETDATA_LENGTH_String[];
EXTERN char MCSync_A2DP_OLDAGENT_IS_ALLOW_String[];
EXTERN char MCSync_A2DP_OLDAGENT_RECORDMSG_String1[];
EXTERN char MCSync_A2DP_OLDAGENT_RECORDMSG_String2[];
EXTERN char MCSync_A2DP_OLDAGENT_RECORDMSG_ERROR_String1[];
EXTERN char MCSync_A2DP_OLDAGENT_RECORDMSG_ERROR_String2[];

/* AVRCP RHO */
EXTERN char MCSync_AVRCP_NEWAGENT_ASSIGN_String1[];
EXTERN char MCSync_AVRCP_NEWAGENT_ASSIGN_String2[];
EXTERN char MCSync_AVRCP_OLDAGENT_FILL_String1[];
EXTERN char MCSync_AVRCP_OLDAGENT_FILL_String2[];
EXTERN char MCSync_AVRCP_NEWPARTNER_APPLY_String[];
EXTERN char MCSync_AVRCP_NEWAGENT_APPLY_String[];
EXTERN char MCSync_AVRCP_NEWAGENT_APPLY_ERROR_String1[];
EXTERN char MCSync_AVRCP_NEWAGENT_APPLY_ERROR_String2[];
EXTERN char MCSync_AVRCP_NEWAGENT_APPLY_ERROR_String3[];
EXTERN char MCSync_AVRCP_NEWAGENT_APPLY_SUCCESS_String[];
EXTERN char MCSync_AVRCP_OLDAGENT_GETDATA_ERROR_String1[];
EXTERN char MCSync_AVRCP_OLDAGENT_GETDATA_ERROR_String2[];
EXTERN char MCSync_AVRCP_OLDAGENT_GETDATA_ERROR_String3[];
EXTERN char MCSync_AVRCP_OLDAGENT_GETDATA_POPQ_String[];
EXTERN char MCSync_AVRCP_OLDAGENT_GETDATA_LENGTH_String[];
EXTERN char MCSync_AVRCP_OLDAGENT_IS_ALLOW_String[];
EXTERN char MCSync_AVRCP_OLDAGENT_RECORDMSG_String1[];
EXTERN char MCSync_AVRCP_OLDAGENT_RECORDMSG_String2[];
EXTERN char MCSync_AVRCP_OLDAGENT_RECORDMSG_ERROR_String1[];
EXTERN char MCSync_AVRCP_OLDAGENT_RECORDMSG_ERROR_String2[];

/* MCSync RHO  */
EXTERN char MCSync_MCSync_NEWAGENT_ASSIGN_String1[];
EXTERN char MCSync_MCSync_NEWAGENT_ASSIGN_String2[];
EXTERN char MCSync_MCSync_NEWAGENT_ASSIGN_String3[];
EXTERN char MCSync_MCSync_OLDAGENT_FILL_String1[];
EXTERN char MCSync_MCSync_OLDAGENT_FILL_String2[];
EXTERN char MCSync_MCSync_NEWPARTNER_APPLY_String1[];
EXTERN char MCSync_MCSync_NEWPARTNER_APPLY_String2[];
EXTERN char MCSync_MCSync_NEWPARTNER_APPLY_String3[];
EXTERN char MCSync_MCSync_NEWAGENT_APPLY_String[];
EXTERN char MCSync_MCSync_NEWAGENT_APPLY_ERROR_String1[];
EXTERN char MCSync_MCSync_NEWAGENT_APPLY_ERROR_String2[];
EXTERN char MCSync_MCSync_NEWAGENT_APPLY_ERROR_String3[];
EXTERN char MCSync_MCSync_NEWAGENT_APPLY_SUCCESS_String[];
EXTERN char MCSync_MCSync_OLDAGENT_GETDATA_ERROR_String1[];
EXTERN char MCSync_MCSync_OLDAGENT_GETDATA_ERROR_String2[];
EXTERN char MCSync_MCSync_OLDAGENT_GETDATA_ERROR_String3[];
EXTERN char MCSync_MCSync_OLDAGENT_GETDATA_POPQ_String[];
EXTERN char MCSync_MCSync_OLDAGENT_GETDATA_LENGTH_String[];
EXTERN char MCSync_MCSync_OLDAGENT_IS_ALLOW_String[];
EXTERN char MCSync_MCSync_OLDAGENT_RECORDMSG_String1[];
EXTERN char MCSync_MCSync_OLDAGENT_RECORDMSG_String2[];
EXTERN char MCSync_MCSync_OLDAGENT_RECORDMSG_ERROR_String1[];
EXTERN char MCSync_MCSync_OLDAGENT_RECORDMSG_ERROR_String2[];

/* HFP RHO  */
EXTERN char MCSync_HFP_NEWAGENT_ASSIGN_String1[];
EXTERN char MCSync_HFP_NEWAGENT_ASSIGN_String2[];
EXTERN char MCSync_HFP_OLDAGENT_FILL_String1[];
EXTERN char MCSync_HFP_OLDAGENT_FILL_String2[];
EXTERN char MCSync_HFP_NEWPARTNER_APPLY_String[];
EXTERN char MCSync_HFP_NEWAGENT_APPLY_String[];
EXTERN char MCSync_HFP_NEWAGENT_APPLY_ERROR_String1[];
EXTERN char MCSync_HFP_NEWAGENT_APPLY_ERROR_String2[];
EXTERN char MCSync_HFP_NEWAGENT_APPLY_ERROR_String3[];
EXTERN char MCSync_HFP_NEWAGENT_APPLY_SUCCESS_String[];
EXTERN char MCSync_HFP_OLDAGENT_GETDATA_ERROR_String1[];
EXTERN char MCSync_HFP_OLDAGENT_GETDATA_ERROR_String2[];
EXTERN char MCSync_HFP_OLDAGENT_GETDATA_ERROR_String3[];
EXTERN char MCSync_HFP_OLDAGENT_GETDATA_POPQ_String[];
EXTERN char MCSync_HFP_OLDAGENT_GETDATA_LENGTH_String[];
EXTERN char MCSync_HFP_OLDAGENT_IS_ALLOW_String[];
EXTERN char MCSync_HFP_OLDAGENT_RECORDMSG_String1[];
EXTERN char MCSync_HFP_OLDAGENT_RECORDMSG_String2[];
EXTERN char MCSync_HFP_OLDAGENT_RECORDMSG_ERROR_String1[];
EXTERN char MCSync_HFP_OLDAGENT_RECORDMSG_ERROR_String2[];

/* PM RHO */
EXTERN char MCSync_PM_NEWAGENT_ASSIGN_ERROR_String1[];
EXTERN char MCSync_PM_NEWAGENT_ASSIGN_ERROR_String2[];
EXTERN char MCSync_PM_NEWAGENT_ASSIGN_SUCCESS_String[];
EXTERN char MCSync_PM_OLDAGENT_FILL_String1[];
EXTERN char MCSync_PM_OLDAGENT_FILL_String2[];
EXTERN char MCSync_PM_NEWPARTNER_APPLY_String[];
EXTERN char MCSync_PM_NEWAGENT_APPLY_String[];
EXTERN char MCSync_PM_NEWAGENT_APPLY_ERROR_String1[];
EXTERN char MCSync_PM_NEWAGENT_APPLY_ERROR_String2[];
EXTERN char MCSync_PM_NEWAGENT_APPLY_ERROR_String3[];
EXTERN char MCSync_PM_NEWAGENT_APPLY_SUCCESS_String[];
EXTERN char MCSync_PM_OLDAGENT_GETDATA_ERROR_String1[];
EXTERN char MCSync_PM_OLDAGENT_GETDATA_ERROR_String2[];
EXTERN char MCSync_PM_OLDAGENT_GETDATA_ERROR_String3[];
EXTERN char MCSync_PM_OLDAGENT_GETDATA_POPQ_String[];
EXTERN char MCSync_PM_OLDAGENT_GETDATA_LENGTH_String[];
EXTERN char MCSync_PM_OLDAGENT_IS_ALLOW_String[];
EXTERN char MCSync_PM_OLDAGENT_RECORDMSG_String1[];
EXTERN char MCSync_PM_OLDAGENT_RECORDMSG_String2[];
EXTERN char MCSync_PM_OLDAGENT_RECORDMSG_ERROR_String1[];
EXTERN char MCSync_PM_OLDAGENT_RECORDMSG_ERROR_String2[];

/* APP RHO Handler */
EXTERN char MCSync_APP_NEWPARTNER_APPLY_String[];
EXTERN char MCSync_APP_NEWAGENT_APPLY_String[];
EXTERN char MCSync_APP_NEWAGENT_APPLY_ERROR_String1[];
EXTERN char MCSync_APP_NEWAGENT_APPLY_ERROR_String2[];
EXTERN char MCSync_APP_NEWAGENT_APPLY_ERROR_String3[];
EXTERN char MCSync_APP_NEWAGENT_APPLY_SUCCESS_String[];
EXTERN char MCSync_APP_OLDAGENT_GETDATA_ERROR_String1[];
EXTERN char MCSync_APP_OLDAGENT_GETDATA_ERROR_String2[];
EXTERN char MCSync_APP_OLDAGENT_GETDATA_ERROR_String3[];
EXTERN char MCSync_APP_OLDAGENT_GETDATA_POPQ_String[];
EXTERN char MCSync_APP_OLDAGENT_GETDATA_LENGTH_String[];
EXTERN char MCSync_APP_OLDAGENT_RECORDMSG_String1[];
EXTERN char MCSync_APP_OLDAGENT_RECORDMSG_String2[];
EXTERN char MCSync_APP_OLDAGENT_RECORDMSG_ERROR_String1[];
EXTERN char MCSync_APP_OLDAGENT_RECORDMSG_ERROR_String2[];
EXTERN char MCSync_APPCONN_OLDAGENT_FILL_ERROR_String[] ;
EXTERN char MCSync_APPCONN_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPAT_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPAT_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPSCO_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPSCO_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPST_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPST_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPSM_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPSM_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPVP_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPVP_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPHFPIMG_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPHFPIMG_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPPWROFF_OLDAGENT_FILL_ERROR_String[];
EXTERN char MCSync_APPPWROFF_NEWAGENT_ASSIGN_ERROR_String[];
EXTERN char MCSync_APPRCECMD_ALLOW_KEYCODE_ERROR_String[];
EXTERN char MCSync_APPRCECMD_ALLOW_CONN_ERROR_String[];
EXTERN char MCSync_APPRCECMD_ALLOW_ANC_ERROR_String[];

/* APP Mcsync Reconnect*/
EXTERN char APP_McsReconn_ReconnTimeout_String[];
EXTERN char APP_McsReconn_StateHandler_String[];
EXTERN char APP_McsReconn_ActionHandler_String[];
EXTERN char APP_McsReconn_SuperReconn_String1[];
EXTERN char APP_McsReconn_SuperReconn_String2[];
EXTERN char APP_McsReconn_SpecialNotReady_String[];
EXTERN char APP_McsReconn_ReconnectNotify_String[];
EXTERN char APP_McsReconn_SetRoleNotify_String[];
EXTERN char APP_McsReconn_EnterSuperReconnMode_String[];
EXTERN char APP_McsReconn_ExitSuperReconnMode_String[];
EXTERN char APP_McsReconn_SetReconnectTime_String[];
EXTERN char APP_McsReconn_ReconnectFailedNotify_String[];
EXTERN char APP_McsReconn_NvkeyInitFailed_String[];
EXTERN char APP_McsReconn_SuperReconnEnd_String[];
EXTERN char APP_McsReconn_SetLinkLossBdAddr_String[];
EXTERN char APP_McsReconn_SetNotReconnMask_String[];
EXTERN char APP_McsReconn_ClearNotReconnMask_String[];
EXTERN char APP_McsReconn_ClearAllNotReconnMask_String[];
EXTERN char APP_McsReconn_SyncNotReconnMask_String[];
EXTERN char APP_McsReconn_IsNeedReconnectAg_String[];

EXTERN char APP_McsReconn_IsReconnAgLinkInfo_String[];
EXTERN char APP_McsReconn_AgentIdleIsReconn_String[];

EXTERN char APP_McsReconn_State_String[][MAX_LOG_STRING];
EXTERN char APP_McsReconn_Action_String[][MAX_LOG_STRING];
EXTERN char APP_McsReconn_Event_String[][MAX_LOG_STRING];
EXTERN char APP_McsReconn_TimerId_String[][MAX_LOG_STRING];

/*Lib Charger*/
EXTERN char APP_ChargerCase_DrvEvt_String[];

/*Smart Charger Case*/
EXTERN char APP_SmartCase_DrvEvt_String[][MAX_LOG_STRING];

EXTERN char LibDrv_SmartCase_OldState[];
EXTERN char LibDrv_SmartCase_SetState[];
EXTERN char LibDrv_Charger_OldState[];
EXTERN char LibDrv_Charger_SetState[];

EXTERN char LibDrv_SmartCase_StateString[][MAX_LOG_STRING];
EXTERN char LibDrv_Charger_StateString[][MAX_LOG_STRING];

/* App Smart Case*/
EXTERN char APP_SmartCase_StateHandler_String[];
EXTERN char APP_SmartCase_TimerHandler_String[];
EXTERN char APP_SmartCase_LinOnHandler_String[];
EXTERN char APP_SmartCase_LidOffHandler_String[];
EXTERN char APP_SmartCase_OutOfCaseHandler_String[];
EXTERN char APP_SmartCase_MCSyncConnTimerHandler_String[];
EXTERN char APP_SmartCase_RhoTimerHandler_String[];
EXTERN char APP_SmartCase_AgentRhoTimerHandler_String[];
EXTERN char APP_SmartCase_CheckNeedToConnectToAG_String[];
EXTERN char APP_SmartCase_CheckIsOutOfCase_String[];
EXTERN char APP_McSyncLinkString[][MAX_LOG_STRING];
EXTERN char APP_LinkConnString[][MAX_LOG_STRING];
EXTERN char APP_SmartCase_LidOnHandler_Checktimer_String[];
EXTERN char APP_SmartCase_IsOutOfCaseSCCState_String[];
EXTERN char APP_SmartCase_IsPhoneNeed_String[];
EXTERN char APP_SmartCase_IsAbleToRHO_String[];
EXTERN char APP_SmartCase_StateInfo_String[];
EXTERN char APP_SmartCase_app_SmtChgCse_RsvHandlerid_String[];
EXTERN char APP_SmartCase_keyCodeSupportState_String[];



/* App AMA*/
EXTERN char APP_AMA_StartServiceCfm_String[];
EXTERN char APP_AMA_StopServiceCfm_String[];
EXTERN char APP_AMA_EnableAdvCfm_String[];
EXTERN char APP_AMA_DisableAdvCfm_String[];
EXTERN char APP_AMA_ConnectCfm_String[];
EXTERN char APP_AMA_DisconnectInd_String[];
EXTERN char APP_AMA_DisconnectCfm_String[];
EXTERN char APP_AMA_StartSpeechCfm_String[];
EXTERN char APP_AMA_ProvideSpeechInd_String[];
EXTERN char APP_AMA_StopSpeechInd_String[];
EXTERN char APP_AMA_StopSpeechCfm_String[];
EXTERN char APP_AMA_EndPointSpeechInd_String[];
EXTERN char APP_AMA_EndPointSpeechCfm_String[];
EXTERN char APP_AMA_SpeechStateInd_String[];
EXTERN char APP_AMA_GetStateCfm_String[];
EXTERN char APP_AMA_GetStateInd_String[];
EXTERN char APP_AMA_SetStateInd_String[];
EXTERN char APP_AMA_SyncStateCfm_String[];
EXTERN char APP_AMA_SyncStateInd_String[];
EXTERN char APP_AMA_MediaControlCfm_String[];
EXTERN char APP_AMA_MediaControlInd_String[];
EXTERN char APP_AMA_ForwardAtCmdInd_String[];
EXTERN char APP_AMA_IncomingCallCfm_String[];
EXTERN char APP_AMA_SwitchTransportInd_String[];
EXTERN char APP_AMA_UpdateDeviceInfoInd_String[];
EXTERN char APP_AMA_GetCentralInfoCfm_String[];
EXTERN char APP_AMA_OverrideAssistantCfm_String[];
EXTERN char APP_AMA_OverrideAssistantInd_String[];
EXTERN char APP_AMA_FactoryResetCfm_String[];
EXTERN char APP_AMA_GetDataCfm_String[];
EXTERN char APP_AMA_UnknownID_String[];

/* App VAD*/
EXTERN char APP_VAD_TimerHandler_String[];
EXTERN char APP_VAD_EventHandler_String[];
EXTERN char APP_VAD_NoiseThdReport_String[];
EXTERN char APP_VAD_SetVadMode_String[];
EXTERN char APP_VAD_SetVadModeState_String[];
EXTERN char APP_VAD_TriggerModeTimer_String[];
EXTERN char APP_VAD_Enable_String[];
EXTERN char APP_VAD_Disable_String[];
EXTERN char APP_VAD_ChangeMode_String[];
EXTERN char APP_VAD_WakeSiri_String[];


EXTERN char SPP_SDP_REG_CFM_STR[];
EXTERN char SPP_SDP_UNREG_CFM_STR[];
EXTERN char SPP_SDP_OPEN_SEARCH_CFM_STR[];
EXTERN char SPP_SDP_CLOSE_SEARCH_CFM_STR[];
EXTERN char SPP_SDP_SERVICE_SEARCH_STR[];
EXTERN char SPP_SDP_ERROR_SRT1[];

EXTERN char APP_CustSPP_StartServiceCfm_String[];
EXTERN char APP_CustSPP_StopServiceCfm_String[];
EXTERN char APP_CustSPP_ConnectCfm_String[];
EXTERN char APP_CustSPP_DisconnectCfm_String[];
EXTERN char APP_CustSPP_TxAvailableInd_String[];
EXTERN char APP_CustSPP_RxDataInd_String[];

/*EXTERN char DBG_HANG_01_String[];
EXTERN char DBG_HANG_02_String[];
EXTERN char DBG_HANG_03_String[];
EXTERN char DBG_HANG_04_String[];
EXTERN char DBG_HANG_05_String[];
EXTERN char DBG_HANG_06_String[];
EXTERN char DBG_HANG_07_String[];
EXTERN char DBG_HANG_08_String[];
EXTERN char DBG_HANG_09_String[];
EXTERN char DBG_HANG_10_String[];
EXTERN char DBG_HANG_11_String[];
EXTERN char DBG_HANG_12_String[];
EXTERN char DBG_HANG_13_String[];
EXTERN char DBG_HANG_14_String[];*/

#ifdef AIROHA_DEBUG
EXTERN VOID logPrint(LOG_PRINTF_GROUP group, PRINTF_LEVEL printLevel, char *logString, U32 argc, ...);
EXTERN VOID logPrintBlocking(LOG_PRINTF_GROUP group, PRINTF_LEVEL printLevel, char *logString, U32 argc, ...);
#else
#define logPrint(x,y,z,j, ...)
#define logPrintBlocking(x,y,z,j, ...)
#endif

#endif /* _LOG_H_ */

